'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var Prism = require('prismjs');
var PropTypes = require('prop-types');
var React = require('react');
var css = require('@emotion/css');
var equal = require('@guanghechen/equal');
var coreReactConstant = require('@yozora/core-react-constant');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var Prism__default = /*#__PURE__*/_interopDefault(Prism);
var PropTypes__default = /*#__PURE__*/_interopDefault(PropTypes);
var React__default = /*#__PURE__*/_interopDefault(React);

Prism__default.default.languages.clike = {
    comment: [
        {
            pattern: /(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,
            lookbehind: true,
            greedy: true,
        },
        {
            pattern: /(^|[^\\:])\/\/.*/,
            lookbehind: true,
            greedy: true,
        },
    ],
    string: {
        pattern: /(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,
        greedy: true,
    },
    'class-name': {
        pattern: /(\b(?:class|extends|implements|instanceof|interface|new|trait)\s+|\bcatch\s+\()[\w.\\]+/i,
        lookbehind: true,
        inside: {
            punctuation: /[.\\]/,
        },
    },
    keyword: /\b(?:break|catch|continue|do|else|finally|for|function|if|in|instanceof|new|null|return|throw|try|while)\b/,
    boolean: /\b(?:false|true)\b/,
    function: /\b\w+(?=\()/,
    number: /\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,
    operator: /[<>]=?|[!=]=?=?|--?|\+\+?|&&?|\|\|?|[?*/~^%]/,
    punctuation: /[{}[\];(),.:]/,
};

Prism__default.default.languages.markup = {
    comment: {
        pattern: /<!--(?:(?!<!--)[\s\S])*?-->/,
        greedy: true,
    },
    prolog: {
        pattern: /<\?[\s\S]+?\?>/,
        greedy: true,
    },
    doctype: {
        pattern: /<!DOCTYPE(?:[^>"'[\]]|"[^"]*"|'[^']*')+(?:\[(?:[^<"'\]]|"[^"]*"|'[^']*'|<(?!!--)|<!--(?:[^-]|-(?!->))*-->)*\]\s*)?>/i,
        greedy: true,
        inside: {
            'internal-subset': {
                pattern: /(^[^[]*\[)[\s\S]+(?=\]>$)/,
                lookbehind: true,
                greedy: true,
                inside: null,
            },
            string: {
                pattern: /"[^"]*"|'[^']*'/,
                greedy: true,
            },
            punctuation: /^<!|>$|[[\]]/,
            'doctype-tag': /^DOCTYPE/i,
            name: /[^\s<>'"]+/,
        },
    },
    cdata: {
        pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i,
        greedy: true,
    },
    tag: {
        pattern: /<\/?(?!\d)[^\s>/=$<%]+(?:\s(?:\s*[^\s>/=]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))|(?=[\s/>])))+)?\s*\/?>/,
        greedy: true,
        inside: {
            tag: {
                pattern: /^<\/?[^\s>/]+/,
                inside: {
                    punctuation: /^<\/?/,
                    namespace: /^[^\s>/:]+:/,
                },
            },
            'special-attr': [],
            'attr-value': {
                pattern: /=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+)/,
                inside: {
                    punctuation: [
                        {
                            pattern: /^=/,
                            alias: 'attr-equals',
                        },
                        {
                            pattern: /^(\s*)["']|["']$/,
                            lookbehind: true,
                        },
                    ],
                },
            },
            punctuation: /\/?>/,
            'attr-name': {
                pattern: /[^\s>/]+/,
                inside: {
                    namespace: /^[^\s>/:]+:/,
                },
            },
        },
    },
    entity: [
        {
            pattern: /&[\da-z]{1,8};/i,
            alias: 'named-entity',
        },
        /&#x?[\da-f]{1,8};/i,
    ],
};
Prism__default.default.languages.markup['tag'].inside['attr-value'].inside['entity'] =
    Prism__default.default.languages.markup['entity'];
Prism__default.default.languages.markup['doctype'].inside['internal-subset'].inside =
    Prism__default.default.languages.markup;
Prism__default.default.hooks.add('wrap', function (env) {
    if (env.type === 'entity' && env.attributes) {
        env.attributes['title'] = env.content.replace(/&amp;/, '&');
    }
});
Object.defineProperty(Prism__default.default.languages.markup.tag, 'addInlined', {
    value: function addInlined(tagName, lang) {
        const includedCdataInside = {};
        includedCdataInside['language-' + lang] = {
            pattern: /(^<!\[CDATA\[)[\s\S]+?(?=\]\]>$)/i,
            lookbehind: true,
            inside: Prism__default.default.languages[lang],
        };
        includedCdataInside['cdata'] = /^<!\[CDATA\[|\]\]>$/i;
        const inside = {
            'included-cdata': {
                pattern: /<!\[CDATA\[[\s\S]*?\]\]>/i,
                inside: includedCdataInside,
            },
        };
        inside['language-' + lang] = {
            pattern: /[\s\S]+/,
            inside: Prism__default.default.languages[lang],
        };
        const def = {};
        def[tagName] = {
            pattern: RegExp(/(<__[^>]*>)(?:<!\[CDATA\[(?:[^\]]|\](?!\]>))*\]\]>|(?!<!\[CDATA\[)[\s\S])*?(?=<\/__>)/.source.replace(/__/g, function () {
                return tagName;
            }), 'i'),
            lookbehind: true,
            greedy: true,
            inside: inside,
        };
        Prism__default.default.languages.insertBefore('markup', 'cdata', def);
    },
});
Object.defineProperty(Prism__default.default.languages.markup.tag, 'addAttribute', {
    value: function (attrName, lang) {
        Prism__default.default.languages.markup.tag.inside['special-attr'].push({
            pattern: RegExp(/(^|["'\s])/.source +
                '(?:' +
                attrName +
                ')' +
                /\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))/.source, 'i'),
            lookbehind: true,
            inside: {
                'attr-name': /^[^\s=]+/,
                'attr-value': {
                    pattern: /=[\s\S]+/,
                    inside: {
                        value: {
                            pattern: /(^=\s*(["']|(?!["'])))\S[\s\S]*(?=\2$)/,
                            lookbehind: true,
                            alias: [lang, 'language-' + lang],
                            inside: Prism__default.default.languages[lang],
                        },
                        punctuation: [
                            {
                                pattern: /^=/,
                                alias: 'attr-equals',
                            },
                            /"|'/,
                        ],
                    },
                },
            },
        });
    },
});
Prism__default.default.languages.html = Prism__default.default.languages.markup;
Prism__default.default.languages.mathml = Prism__default.default.languages.markup;
Prism__default.default.languages.svg = Prism__default.default.languages.markup;
Prism__default.default.languages.xml = Prism__default.default.languages.extend('markup', {});
Prism__default.default.languages.ssml = Prism__default.default.languages.xml;
Prism__default.default.languages.atom = Prism__default.default.languages.xml;
Prism__default.default.languages.rss = Prism__default.default.languages.xml;

const envVars = '\\b(?:BASH|BASHOPTS|BASH_ALIASES|BASH_ARGC|BASH_ARGV|BASH_CMDS|BASH_COMPLETION_COMPAT_DIR|BASH_LINENO|BASH_REMATCH|BASH_SOURCE|BASH_VERSINFO|BASH_VERSION|COLORTERM|COLUMNS|COMP_WORDBREAKS|DBUS_SESSION_BUS_ADDRESS|DEFAULTS_PATH|DESKTOP_SESSION|DIRSTACK|DISPLAY|EUID|GDMSESSION|GDM_LANG|GNOME_KEYRING_CONTROL|GNOME_KEYRING_PID|GPG_AGENT_INFO|GROUPS|HISTCONTROL|HISTFILE|HISTFILESIZE|HISTSIZE|HOME|HOSTNAME|HOSTTYPE|IFS|INSTANCE|JOB|LANG|LANGUAGE|LC_ADDRESS|LC_ALL|LC_IDENTIFICATION|LC_MEASUREMENT|LC_MONETARY|LC_NAME|LC_NUMERIC|LC_PAPER|LC_TELEPHONE|LC_TIME|LESSCLOSE|LESSOPEN|LINES|LOGNAME|LS_COLORS|MACHTYPE|MAILCHECK|MANDATORY_PATH|NO_AT_BRIDGE|OLDPWD|OPTERR|OPTIND|ORBIT_SOCKETDIR|OSTYPE|PAPERSIZE|PATH|PIPESTATUS|PPID|PS1|PS2|PS3|PS4|PWD|RANDOM|REPLY|SECONDS|SELINUX_INIT|SESSION|SESSIONTYPE|SESSION_MANAGER|SHELL|SHELLOPTS|SHLVL|SSH_AUTH_SOCK|TERM|UID|UPSTART_EVENTS|UPSTART_INSTANCE|UPSTART_JOB|UPSTART_SESSION|USER|WINDOWID|XAUTHORITY|XDG_CONFIG_DIRS|XDG_CURRENT_DESKTOP|XDG_DATA_DIRS|XDG_GREETER_DATA_DIR|XDG_MENU_PREFIX|XDG_RUNTIME_DIR|XDG_SEAT|XDG_SEAT_PATH|XDG_SESSION_DESKTOP|XDG_SESSION_ID|XDG_SESSION_PATH|XDG_SESSION_TYPE|XDG_VTNR|XMODIFIERS)\\b';
const commandAfterHeredoc = {
    pattern: /(^(["']?)\w+\2)[ \t]+\S.*/,
    lookbehind: true,
    alias: 'punctuation',
    inside: undefined,
};
const insideString = {
    bash: commandAfterHeredoc,
    environment: {
        pattern: RegExp('\\$' + envVars),
        alias: 'constant',
    },
    variable: [
        {
            pattern: /\$?\(\([\s\S]+?\)\)/,
            greedy: true,
            inside: {
                variable: [
                    {
                        pattern: /(^\$\(\([\s\S]+)\)\)/,
                        lookbehind: true,
                    },
                    /^\$\(\(/,
                ],
                number: /\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/,
                operator: /--|\+\+|\*\*=?|<<=?|>>=?|&&|\|\||[=!+\-*/%<>^&|]=?|[?~:]/,
                punctuation: /\(\(?|\)\)?|,|;/,
            },
        },
        {
            pattern: /\$\((?:\([^)]+\)|[^()])+\)|`[^`]+`/,
            greedy: true,
            inside: {
                variable: /^\$\(|^`|\)$|`$/,
            },
        },
        {
            pattern: /\$\{[^}]+\}/,
            greedy: true,
            inside: {
                operator: /:[-=?+]?|[!/]|##?|%%?|\^\^?|,,?/,
                punctuation: /[[\]]/,
                environment: {
                    pattern: RegExp('(\\{)' + envVars),
                    lookbehind: true,
                    alias: 'constant',
                },
            },
        },
        /\$(?:\w+|[#?*!@$])/,
    ],
    entity: /\\(?:[abceEfnrtv\\"]|O?[0-7]{1,3}|U[0-9a-fA-F]{8}|u[0-9a-fA-F]{4}|x[0-9a-fA-F]{1,2})/,
};
Prism__default.default.languages.bash = {
    shebang: {
        pattern: /^#!\s*\/.*/,
        alias: 'important',
    },
    comment: {
        pattern: /(^|[^"{\\$])#.*/,
        lookbehind: true,
    },
    'function-name': [
        {
            pattern: /(\bfunction\s+)[\w-]+(?=(?:\s*\(?:\s*\))?\s*\{)/,
            lookbehind: true,
            alias: 'function',
        },
        {
            pattern: /\b[\w-]+(?=\s*\(\s*\)\s*\{)/,
            alias: 'function',
        },
    ],
    'for-or-select': {
        pattern: /(\b(?:for|select)\s+)\w+(?=\s+in\s)/,
        alias: 'variable',
        lookbehind: true,
    },
    'assign-left': {
        pattern: /(^|[\s;|&]|[<>]\()\w+(?:\.\w+)*(?=\+?=)/,
        inside: {
            environment: {
                pattern: RegExp('(^|[\\s;|&]|[<>]\\()' + envVars),
                lookbehind: true,
                alias: 'constant',
            },
        },
        alias: 'variable',
        lookbehind: true,
    },
    parameter: {
        pattern: /(^|\s)-{1,2}(?:\w+:[+-]?)?\w+(?:\.\w+)*(?=[=\s]|$)/,
        alias: 'variable',
        lookbehind: true,
    },
    string: [
        {
            pattern: /((?:^|[^<])<<-?\s*)(\w+)\s[\s\S]*?(?:\r?\n|\r)\2/,
            lookbehind: true,
            greedy: true,
            inside: insideString,
        },
        {
            pattern: /((?:^|[^<])<<-?\s*)(["'])(\w+)\2\s[\s\S]*?(?:\r?\n|\r)\3/,
            lookbehind: true,
            greedy: true,
            inside: {
                bash: commandAfterHeredoc,
            },
        },
        {
            pattern: /(^|[^\\](?:\\\\)*)"(?:\\[\s\S]|\$\([^)]+\)|\$(?!\()|`[^`]+`|[^"\\`$])*"/,
            lookbehind: true,
            greedy: true,
            inside: insideString,
        },
        {
            pattern: /(^|[^$\\])'[^']*'/,
            lookbehind: true,
            greedy: true,
        },
        {
            pattern: /\$'(?:[^'\\]|\\[\s\S])*'/,
            greedy: true,
            inside: {
                entity: insideString.entity,
            },
        },
    ],
    environment: {
        pattern: RegExp('\\$?' + envVars),
        alias: 'constant',
    },
    variable: insideString.variable,
    function: {
        pattern: /(^|[\s;|&]|[<>]\()(?:add|apropos|apt|apt-cache|apt-get|aptitude|aspell|automysqlbackup|awk|basename|bash|bc|bconsole|bg|bzip2|cal|cargo|cat|cfdisk|chgrp|chkconfig|chmod|chown|chroot|cksum|clear|cmp|column|comm|composer|cp|cron|crontab|csplit|curl|cut|date|dc|dd|ddrescue|debootstrap|df|diff|diff3|dig|dir|dircolors|dirname|dirs|dmesg|docker|docker-compose|du|egrep|eject|env|ethtool|expand|expect|expr|fdformat|fdisk|fg|fgrep|file|find|fmt|fold|format|free|fsck|ftp|fuser|gawk|git|gparted|grep|groupadd|groupdel|groupmod|groups|grub-mkconfig|gzip|halt|head|hg|history|host|hostname|htop|iconv|id|ifconfig|ifdown|ifup|import|install|ip|java|jobs|join|kill|killall|less|link|ln|locate|logname|logrotate|look|lpc|lpr|lprint|lprintd|lprintq|lprm|ls|lsof|lynx|make|man|mc|mdadm|mkconfig|mkdir|mke2fs|mkfifo|mkfs|mkisofs|mknod|mkswap|mmv|more|most|mount|mtools|mtr|mutt|mv|nano|nc|netstat|nice|nl|node|nohup|notify-send|npm|nslookup|op|open|parted|passwd|paste|pathchk|ping|pkill|pnpm|podman|podman-compose|popd|pr|printcap|printenv|ps|pushd|pv|quota|quotacheck|quotactl|ram|rar|rcp|reboot|remsync|rename|renice|rev|rm|rmdir|rpm|rsync|scp|screen|sdiff|sed|sendmail|seq|service|sftp|sh|shellcheck|shuf|shutdown|sleep|slocate|sort|split|ssh|stat|strace|su|sudo|sum|suspend|swapon|sync|sysctl|tac|tail|tar|tee|time|timeout|top|touch|tr|traceroute|tsort|tty|umount|uname|unexpand|uniq|units|unrar|unshar|unzip|update-grub|uptime|useradd|userdel|usermod|users|uudecode|uuencode|v|vcpkg|vdir|vi|vim|virsh|vmstat|wait|watch|wc|wget|whereis|which|who|whoami|write|xargs|xdg-open|yarn|yes|zenity|zip|zsh|zypper)(?=$|[)\s;|&])/,
        lookbehind: true,
    },
    keyword: {
        pattern: /(^|[\s;|&]|[<>]\()(?:case|do|done|elif|else|esac|fi|for|function|if|in|select|then|until|while)(?=$|[)\s;|&])/,
        lookbehind: true,
    },
    builtin: {
        pattern: /(^|[\s;|&]|[<>]\()(?:\.|:|alias|bind|break|builtin|caller|cd|command|continue|declare|echo|enable|eval|exec|exit|export|getopts|hash|help|let|local|logout|mapfile|printf|pwd|read|readarray|readonly|return|set|shift|shopt|source|test|times|trap|type|typeset|ulimit|umask|unalias|unset)(?=$|[)\s;|&])/,
        lookbehind: true,
        alias: 'class-name',
    },
    boolean: {
        pattern: /(^|[\s;|&]|[<>]\()(?:false|true)(?=$|[)\s;|&])/,
        lookbehind: true,
    },
    'file-descriptor': {
        pattern: /\B&\d\b/,
        alias: 'important',
    },
    operator: {
        pattern: /\d?<>|>\||\+=|=[=~]?|!=?|<<[<-]?|[&\d]?>>|\d[<>]&?|[<>][&=]?|&[>&]?|\|[&|]?/,
        inside: {
            'file-descriptor': {
                pattern: /^\d/,
                alias: 'important',
            },
        },
    },
    punctuation: /\$?\(\(?|\)\)?|\.\.|[{}[\];\\]/,
    number: {
        pattern: /(^|\s)(?:[1-9]\d*|0)(?:[.,]\d+)?\b/,
        lookbehind: true,
    },
};
commandAfterHeredoc.inside = Prism__default.default.languages.bash;
const toBeCopied = [
    'comment',
    'function-name',
    'for-or-select',
    'assign-left',
    'parameter',
    'string',
    'environment',
    'function',
    'keyword',
    'builtin',
    'boolean',
    'file-descriptor',
    'operator',
    'punctuation',
    'number',
];
const inside$1 = insideString.variable[1].inside;
for (let i = 0; i < toBeCopied.length; i++) {
    inside$1[toBeCopied[i]] = Prism__default.default.languages.bash[toBeCopied[i]];
}
Prism__default.default.languages.sh = Prism__default.default.languages.bash;
Prism__default.default.languages.shell = Prism__default.default.languages.bash;

Prism__default.default.languages.c = Prism__default.default.languages.extend('clike', {
    comment: {
        pattern: /\/\/(?:[^\r\n\\]|\\(?:\r\n?|\n|(?![\r\n])))*|\/\*[\s\S]*?(?:\*\/|$)/,
        greedy: true,
    },
    string: {
        pattern: /"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"/,
        greedy: true,
    },
    'class-name': {
        pattern: /(\b(?:enum|struct)\s+(?:__attribute__\s*\(\([\s\S]*?\)\)\s*)?)\w+|\b[a-z]\w*_t\b/,
        lookbehind: true,
    },
    keyword: /\b(?:_Alignas|_Alignof|_Atomic|_Bool|_Complex|_Generic|_Imaginary|_Noreturn|_Static_assert|_Thread_local|__attribute__|asm|auto|break|case|char|const|continue|default|do|double|else|enum|extern|float|for|goto|if|inline|int|long|register|return|short|signed|sizeof|static|struct|switch|typedef|typeof|union|unsigned|void|volatile|while)\b/,
    function: /\b[a-z_]\w*(?=\s*\()/i,
    number: /(?:\b0x(?:[\da-f]+(?:\.[\da-f]*)?|\.[\da-f]+)(?:p[+-]?\d+)?|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)[ful]{0,4}/i,
    operator: />>=?|<<=?|->|([-+&|:])\1|[?:~]|[-+*/%&|^!=<>]=?/,
});
Prism__default.default.languages.insertBefore('c', 'string', {
    char: {
        pattern: /'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n]){0,32}'/,
        greedy: true,
    },
});
Prism__default.default.languages.insertBefore('c', 'string', {
    macro: {
        pattern: /(^[\t ]*)#\s*[a-z](?:[^\r\n\\/]|\/(?!\*)|\/\*(?:[^*]|\*(?!\/))*\*\/|\\(?:\r\n|[\s\S]))*/im,
        lookbehind: true,
        greedy: true,
        alias: 'property',
        inside: {
            string: [
                {
                    pattern: /^(#\s*include\s*)<[^>]+>/,
                    lookbehind: true,
                },
                Prism__default.default.languages.c['string'],
            ],
            char: Prism__default.default.languages.c['char'],
            comment: Prism__default.default.languages.c['comment'],
            'macro-name': [
                {
                    pattern: /(^#\s*define\s+)\w+\b(?!\()/i,
                    lookbehind: true,
                },
                {
                    pattern: /(^#\s*define\s+)\w+\b(?=\()/i,
                    lookbehind: true,
                    alias: 'function',
                },
            ],
            directive: {
                pattern: /^(#\s*)[a-z]+/,
                lookbehind: true,
                alias: 'keyword',
            },
            'directive-hash': /^#/,
            punctuation: /##|\\(?=[\r\n])/,
            expression: {
                pattern: /\S[\s\S]*/,
                inside: Prism__default.default.languages.c,
            },
        },
    },
});
Prism__default.default.languages.insertBefore('c', 'function', {
    constant: /\b(?:EOF|NULL|SEEK_CUR|SEEK_END|SEEK_SET|__DATE__|__FILE__|__LINE__|__TIMESTAMP__|__TIME__|__func__|stderr|stdin|stdout)\b/,
});
delete Prism__default.default.languages.c.boolean;

const string$1 = /(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/;
Prism__default.default.languages.css = {
    comment: /\/\*[\s\S]*?\*\//,
    atrule: {
        pattern: RegExp('@[\\w-](?:' +
            /[^;{\s"']|\s+(?!\s)/.source +
            '|' +
            string$1.source +
            ')*?' +
            /(?:;|(?=\s*\{))/.source),
        inside: {
            rule: /^@[\w-]+/,
            'selector-function-argument': {
                pattern: /(\bselector\s*\(\s*(?![\s)]))(?:[^()\s]|\s+(?![\s)])|\((?:[^()]|\([^()]*\))*\))+(?=\s*\))/,
                lookbehind: true,
                alias: 'selector',
            },
            keyword: {
                pattern: /(^|[^\w-])(?:and|not|only|or)(?![\w-])/,
                lookbehind: true,
            },
        },
    },
    url: {
        pattern: RegExp('\\burl\\((?:' + string$1.source + '|' + /(?:[^\\\r\n()"']|\\[\s\S])*/.source + ')\\)', 'i'),
        greedy: true,
        inside: {
            function: /^url/i,
            punctuation: /^\(|\)$/,
            string: {
                pattern: RegExp('^' + string$1.source + '$'),
                alias: 'url',
            },
        },
    },
    selector: {
        pattern: RegExp('(^|[{}\\s])[^{}\\s](?:[^{};"\'\\s]|\\s+(?![\\s{])|' + string$1.source + ')*(?=\\s*\\{)'),
        lookbehind: true,
    },
    string: {
        pattern: string$1,
        greedy: true,
    },
    property: {
        pattern: /(^|[^-\w\xA0-\uFFFF])(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*(?=\s*:)/i,
        lookbehind: true,
    },
    important: /!important\b/i,
    function: {
        pattern: /(^|[^-a-z0-9])[-a-z0-9]+(?=\()/i,
        lookbehind: true,
    },
    punctuation: /[(){};:,]/,
};
Prism__default.default.languages.css['atrule'].inside.rest = Prism__default.default.languages.css;
const markup = Prism__default.default.languages.markup;
if (markup) {
    markup.tag.addInlined('style', 'css');
    markup.tag.addAttribute('style', 'css');
}

const keyword = /\b(?:alignas|alignof|asm|auto|bool|break|case|catch|char|char16_t|char32_t|char8_t|class|co_await|co_return|co_yield|compl|concept|const|const_cast|consteval|constexpr|constinit|continue|decltype|default|delete|do|double|dynamic_cast|else|enum|explicit|export|extern|final|float|for|friend|goto|if|import|inline|int|int16_t|int32_t|int64_t|int8_t|long|module|mutable|namespace|new|noexcept|nullptr|operator|override|private|protected|public|register|reinterpret_cast|requires|return|short|signed|sizeof|static|static_assert|static_cast|struct|switch|template|this|thread_local|throw|try|typedef|typeid|typename|uint16_t|uint32_t|uint64_t|uint8_t|union|unsigned|using|virtual|void|volatile|wchar_t|while)\b/;
const modName = /\b(?!<keyword>)\w+(?:\s*\.\s*\w+)*\b/.source.replace(/<keyword>/g, function () {
    return keyword.source;
});
Prism__default.default.languages.cpp = Prism__default.default.languages.extend('c', {
    'class-name': [
        {
            pattern: RegExp(/(\b(?:class|concept|enum|struct|typename)\s+)(?!<keyword>)\w+/.source.replace(/<keyword>/g, function () {
                return keyword.source;
            })),
            lookbehind: true,
        },
        /\b[A-Z]\w*(?=\s*::\s*\w+\s*\()/,
        /\b[A-Z_]\w*(?=\s*::\s*~\w+\s*\()/i,
        /\b\w+(?=\s*<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>\s*::\s*\w+\s*\()/,
    ],
    keyword: keyword,
    number: {
        pattern: /(?:\b0b[01']+|\b0x(?:[\da-f']+(?:\.[\da-f']*)?|\.[\da-f']+)(?:p[+-]?[\d']+)?|(?:\b[\d']+(?:\.[\d']*)?|\B\.[\d']+)(?:e[+-]?[\d']+)?)[ful]{0,4}/i,
        greedy: true,
    },
    operator: />>=?|<<=?|->|--|\+\+|&&|\|\||[?:~]|<=>|[-+*/%&|^!=<>]=?|\b(?:and|and_eq|bitand|bitor|not|not_eq|or|or_eq|xor|xor_eq)\b/,
    boolean: /\b(?:false|true)\b/,
});
Prism__default.default.languages.insertBefore('cpp', 'string', {
    module: {
        pattern: RegExp(/(\b(?:import|module)\s+)/.source +
            '(?:' +
            /"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|<[^<>\r\n]*>/.source +
            '|' +
            /<mod-name>(?:\s*:\s*<mod-name>)?|:\s*<mod-name>/.source.replace(/<mod-name>/g, function () {
                return modName;
            }) +
            ')'),
        lookbehind: true,
        greedy: true,
        inside: {
            string: /^[<"][\s\S]+/,
            operator: /:/,
            punctuation: /\./,
        },
    },
    'raw-string': {
        pattern: /R"([^()\\ ]{0,16})\([\s\S]*?\)\1"/,
        alias: 'string',
        greedy: true,
    },
});
Prism__default.default.languages.insertBefore('cpp', 'keyword', {
    'generic-function': {
        pattern: /\b(?!operator\b)[a-z_]\w*\s*<(?:[^<>]|<[^<>]*>)*>(?=\s*\()/i,
        inside: {
            function: /^\w+/,
            generic: {
                pattern: /<[\s\S]+/,
                alias: 'class-name',
                inside: Prism__default.default.languages.cpp,
            },
        },
    },
});
Prism__default.default.languages.insertBefore('cpp', 'operator', {
    'double-colon': {
        pattern: /::/,
        alias: 'punctuation',
    },
});
Prism__default.default.languages.insertBefore('cpp', 'class-name', {
    'base-clause': {
        pattern: /(\b(?:class|struct)\s+\w+\s*:\s*)[^;{}"'\s]+(?:\s+[^;{}"'\s]+)*(?=\s*[;{])/,
        lookbehind: true,
        greedy: true,
        inside: Prism__default.default.languages.extend('cpp', {}),
    },
});
Prism__default.default.languages.insertBefore('inside', 'double-colon', {
    'class-name': /\b[a-z_]\w*\b(?!\s*::)/i,
}, Prism__default.default.languages.cpp['base-clause']);

const ID = '(?:' +
    [
        /[a-zA-Z_\x80-\uFFFF][\w\x80-\uFFFF]*/.source,
        /-?(?:\.\d+|\d+(?:\.\d*)?)/.source,
        /"[^"\\]*(?:\\[\s\S][^"\\]*)*"/.source,
        /<(?:[^<>]|(?!<!--)<(?:[^<>"']|"[^"]*"|'[^']*')+>|<!--(?:[^-]|-(?!->))*-->)*>/.source,
    ].join('|') +
    ')';
const IDInside = {
    markup: {
        pattern: /(^<)[\s\S]+(?=>$)/,
        lookbehind: true,
        alias: ['language-markup', 'language-html', 'language-xml'],
        inside: Prism__default.default.languages.markup,
    },
};
function withID(source, flags) {
    return RegExp(source.replace(/<ID>/g, function () {
        return ID;
    }), flags);
}
Prism__default.default.languages.dot = {
    comment: {
        pattern: /\/\/.*|\/\*[\s\S]*?\*\/|^#.*/m,
        greedy: true,
    },
    'graph-name': {
        pattern: withID(/(\b(?:digraph|graph|subgraph)[ \t\r\n]+)<ID>/.source, 'i'),
        lookbehind: true,
        greedy: true,
        alias: 'class-name',
        inside: IDInside,
    },
    'attr-value': {
        pattern: withID(/(=[ \t\r\n]*)<ID>/.source),
        lookbehind: true,
        greedy: true,
        inside: IDInside,
    },
    'attr-name': {
        pattern: withID(/([[;, \t\r\n])<ID>(?=[ \t\r\n]*=)/.source),
        lookbehind: true,
        greedy: true,
        inside: IDInside,
    },
    keyword: /\b(?:digraph|edge|graph|node|strict|subgraph)\b/i,
    'compass-point': {
        pattern: /(:[ \t\r\n]*)(?:[ewc_]|[ns][ew]?)(?![\w\x80-\uFFFF])/,
        lookbehind: true,
        alias: 'builtin',
    },
    node: {
        pattern: withID(/(^|[^-.\w\x80-\uFFFF\\])<ID>/.source),
        lookbehind: true,
        greedy: true,
        inside: IDInside,
    },
    operator: /[=:]|-[->]/,
    punctuation: /[[\]{};,]/,
};
Prism__default.default.languages.gv = Prism__default.default.languages.dot;

Prism__default.default.languages.diff = {
    coord: [
        /^(?:\*{3}|-{3}|\+{3}).*$/m,
        /^@@.*@@$/m,
        /^\d.*$/m,
    ],
};
const PREFIXES = {
    'deleted-sign': '-',
    'deleted-arrow': '<',
    'inserted-sign': '+',
    'inserted-arrow': '>',
    unchanged: ' ',
    diff: '!',
};
Object.keys(PREFIXES).forEach(function (name) {
    const prefix = PREFIXES[name];
    const alias = [];
    if (!/^\w+$/.test(name)) {
        alias.push(/\w+/.exec(name)[0]);
    }
    if (name === 'diff') {
        alias.push('bold');
    }
    Prism__default.default.languages.diff[name] = {
        pattern: RegExp('^(?:[' + prefix + '].*(?:\r\n?|\n|(?![\\s\\S])))+', 'm'),
        alias: alias,
        inside: {
            line: {
                pattern: /(.)(?=[\s\S]).*(?:\r\n?|\n)?/,
                lookbehind: true,
            },
            prefix: {
                pattern: /[\s\S]/,
                alias: /\w+/.exec(name)[0],
            },
        },
    };
});
Object.defineProperty(Prism__default.default.languages.diff, 'PREFIXES', {
    value: PREFIXES,
});

Prism__default.default.languages.git = {
    comment: /^#.*/m,
    deleted: /^[-–].*/m,
    inserted: /^\+.*/m,
    string: /("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,
    command: {
        pattern: /^.*\$ git .*$/m,
        inside: {
            parameter: /\s--?\w+/,
        },
    },
    coord: /^@@.*@@$/m,
    'commit-sha1': /^commit \w{40}$/m,
};

Prism__default.default.languages.go = Prism__default.default.languages.extend('clike', {
    string: {
        pattern: /(^|[^\\])"(?:\\.|[^"\\\r\n])*"|`[^`]*`/,
        lookbehind: true,
        greedy: true,
    },
    keyword: /\b(?:break|case|chan|const|continue|default|defer|else|fallthrough|for|func|go(?:to)?|if|import|interface|map|package|range|return|select|struct|switch|type|var)\b/,
    boolean: /\b(?:_|false|iota|nil|true)\b/,
    number: [
        /\b0(?:b[01_]+|o[0-7_]+)i?\b/i,
        /\b0x(?:[a-f\d_]+(?:\.[a-f\d_]*)?|\.[a-f\d_]+)(?:p[+-]?\d+(?:_\d+)*)?i?(?!\w)/i,
        /(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?[\d_]+)?i?(?!\w)/i,
    ],
    operator: /[*/%^!=]=?|\+[=+]?|-[=-]?|\|[=|]?|&(?:=|&|\^=?)?|>(?:>=?|=)?|<(?:<=?|=|-)?|:=|\.\.\./,
    builtin: /\b(?:append|bool|byte|cap|close|complex|complex(?:64|128)|copy|delete|error|float(?:32|64)|u?int(?:8|16|32|64)?|imag|len|make|new|panic|print(?:ln)?|real|recover|rune|string|uintptr)\b/,
});
Prism__default.default.languages.insertBefore('go', 'string', {
    char: {
        pattern: /'(?:\\.|[^'\\\r\n]){0,10}'/,
        greedy: true,
    },
});
delete Prism__default.default.languages.go['class-name'];

const keywords = /\b(?:abstract|assert|boolean|break|byte|case|catch|char|class|const|continue|default|do|double|else|enum|exports|extends|final|finally|float|for|goto|if|implements|import|instanceof|int|interface|long|module|native|new|non-sealed|null|open|opens|package|permits|private|protected|provides|public|record(?!\s*[(){}[\]<>=%~.:,;?+\-*/&|^])|requires|return|sealed|short|static|strictfp|super|switch|synchronized|this|throw|throws|to|transient|transitive|try|uses|var|void|volatile|while|with|yield)\b/;
const classNamePrefix = /(?:[a-z]\w*\s*\.\s*)*(?:[A-Z]\w*\s*\.\s*)*/.source;
const className = {
    pattern: RegExp(/(^|[^\w.])/.source + classNamePrefix + /[A-Z](?:[\d_A-Z]*[a-z]\w*)?\b/.source),
    lookbehind: true,
    inside: {
        namespace: {
            pattern: /^[a-z]\w*(?:\s*\.\s*[a-z]\w*)*(?:\s*\.)?/,
            inside: {
                punctuation: /\./,
            },
        },
        punctuation: /\./,
    },
};
Prism__default.default.languages.java = Prism__default.default.languages.extend('clike', {
    string: {
        pattern: /(^|[^\\])"(?:\\.|[^"\\\r\n])*"/,
        lookbehind: true,
        greedy: true,
    },
    'class-name': [
        className,
        {
            pattern: RegExp(/(^|[^\w.])/.source +
                classNamePrefix +
                /[A-Z]\w*(?=\s+\w+\s*[;,=()]|\s*(?:\[[\s,]*\]\s*)?::\s*new\b)/.source),
            lookbehind: true,
            inside: className.inside,
        },
        {
            pattern: RegExp(/(\b(?:class|enum|extends|implements|instanceof|interface|new|record|throws)\s+)/.source +
                classNamePrefix +
                /[A-Z]\w*\b/.source),
            lookbehind: true,
            inside: className.inside,
        },
    ],
    keyword: keywords,
    function: [
        Prism__default.default.languages.clike.function,
        {
            pattern: /(::\s*)[a-z_]\w*/,
            lookbehind: true,
        },
    ],
    number: /\b0b[01][01_]*L?\b|\b0x(?:\.[\da-f_p+-]+|[\da-f_]+(?:\.[\da-f_p+-]+)?)\b|(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?\d[\d_]*)?[dfl]?/i,
    operator: {
        pattern: /(^|[^.])(?:<<=?|>>>?=?|->|--|\+\+|&&|\|\||::|[?:~]|[-+*/%&|^!=<>]=?)/m,
        lookbehind: true,
    },
    constant: /\b[A-Z][A-Z_\d]+\b/,
});
Prism__default.default.languages.insertBefore('java', 'string', {
    'triple-quoted-string': {
        pattern: /"""[ \t]*[\r\n](?:(?:"|"")?(?:\\.|[^"\\]))*"""/,
        greedy: true,
        alias: 'string',
    },
    char: {
        pattern: /'(?:\\.|[^'\\\r\n]){1,6}'/,
        greedy: true,
    },
});
Prism__default.default.languages.insertBefore('java', 'class-name', {
    annotation: {
        pattern: /(^|[^.])@\w+(?:\s*\.\s*\w+)*/,
        lookbehind: true,
        alias: 'punctuation',
    },
    generics: {
        pattern: /<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&))*>)*>)*>)*>/,
        inside: {
            'class-name': className,
            keyword: keywords,
            punctuation: /[<>(),.:]/,
            operator: /[?&|]/,
        },
    },
    import: [
        {
            pattern: RegExp(/(\bimport\s+)/.source + classNamePrefix + /(?:[A-Z]\w*|\*)(?=\s*;)/.source),
            lookbehind: true,
            inside: {
                namespace: className.inside.namespace,
                punctuation: /\./,
                operator: /\*/,
                'class-name': /\w+/,
            },
        },
        {
            pattern: RegExp(/(\bimport\s+static\s+)/.source + classNamePrefix + /(?:\w+|\*)(?=\s*;)/.source),
            lookbehind: true,
            alias: 'static',
            inside: {
                namespace: className.inside.namespace,
                static: /\b\w+$/,
                punctuation: /\./,
                operator: /\*/,
                'class-name': /\w+/,
            },
        },
    ],
    namespace: {
        pattern: RegExp(/(\b(?:exports|import(?:\s+static)?|module|open|opens|package|provides|requires|to|transitive|uses|with)\s+)(?!<keyword>)[a-z]\w*(?:\.[a-z]\w*)*\.?/.source.replace(/<keyword>/g, function () {
            return keywords.source;
        })),
        lookbehind: true,
        inside: {
            punctuation: /\./,
        },
    },
});

Prism__default.default.languages.javascript = Prism__default.default.languages.extend('clike', {
    'class-name': [
        Prism__default.default.languages.clike['class-name'],
        {
            pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$A-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\.(?:constructor|prototype))/,
            lookbehind: true,
        },
    ],
    keyword: [
        {
            pattern: /((?:^|\})\s*)catch\b/,
            lookbehind: true,
        },
        {
            pattern: /(^|[^.]|\.\.\.\s*)\b(?:as|assert(?=\s*\{)|async(?=\s*(?:function\b|\(|[$\w\xA0-\uFFFF]|$))|await|break|case|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally(?=\s*(?:\{|$))|for|from(?=\s*(?:['"]|$))|function|(?:get|set)(?=\s*(?:[#[$\w\xA0-\uFFFF]|$))|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)\b/,
            lookbehind: true,
        },
    ],
    function: /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*(?:\.\s*(?:apply|bind|call)\s*)?\()/,
    number: {
        pattern: RegExp(/(^|[^\w$])/.source +
            '(?:' +
            (/NaN|Infinity/.source +
                '|' +
                /0[bB][01]+(?:_[01]+)*n?/.source +
                '|' +
                /0[oO][0-7]+(?:_[0-7]+)*n?/.source +
                '|' +
                /0[xX][\dA-Fa-f]+(?:_[\dA-Fa-f]+)*n?/.source +
                '|' +
                /\d+(?:_\d+)*n/.source +
                '|' +
                /(?:\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[Ee][+-]?\d+(?:_\d+)*)?/
                    .source) +
            ')' +
            /(?![\w$])/.source),
        lookbehind: true,
    },
    operator: /--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/,
});
Prism__default.default.languages.javascript['class-name'][0].pattern =
    /(\b(?:class|extends|implements|instanceof|interface|new)\s+)[\w.\\]+/;
Prism__default.default.languages.insertBefore('javascript', 'keyword', {
    regex: {
        pattern: RegExp(/((?:^|[^$\w\xA0-\uFFFF."'\])\s]|\b(?:return|yield))\s*)/.source +
            /\//.source +
            '(?:' +
            /(?:\[(?:[^\]\\\r\n]|\\.)*\]|\\.|[^/\\[\r\n])+\/[dgimyus]{0,7}/.source +
            '|' +
            /(?:\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.)*\])*\])*\]|\\.|[^/\\[\r\n])+\/[dgimyus]{0,7}v[dgimyus]{0,7}/
                .source +
            ')' +
            /(?=(?:\s|\/\*(?:[^*]|\*(?!\/))*\*\/)*(?:$|[\r\n,.;:})\]]|\/\/))/.source),
        lookbehind: true,
        greedy: true,
        inside: {
            'regex-source': {
                pattern: /^(\/)[\s\S]+(?=\/[a-z]*$)/,
                lookbehind: true,
                alias: 'language-regex',
                inside: Prism__default.default.languages.regex,
            },
            'regex-delimiter': /^\/|\/$/,
            'regex-flags': /^[a-z]+$/,
        },
    },
    'function-variable': {
        pattern: /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:async\s*)?(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/,
        alias: 'function',
    },
    parameter: [
        {
            pattern: /(function(?:\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)?\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\))/,
            lookbehind: true,
            inside: Prism__default.default.languages.javascript,
        },
        {
            pattern: /(^|[^$\w\xA0-\uFFFF])(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=>)/i,
            lookbehind: true,
            inside: Prism__default.default.languages.javascript,
        },
        {
            pattern: /(\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*=>)/,
            lookbehind: true,
            inside: Prism__default.default.languages.javascript,
        },
        {
            pattern: /((?:\b|\s|^)(?!(?:as|async|await|break|case|catch|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)(?![$\w\xA0-\uFFFF]))(?:(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*)\(\s*|\]\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*\{)/,
            lookbehind: true,
            inside: Prism__default.default.languages.javascript,
        },
    ],
    constant: /\b[A-Z](?:[A-Z_]|\dx?)*\b/,
});
Prism__default.default.languages.insertBefore('javascript', 'string', {
    hashbang: {
        pattern: /^#!.*/,
        greedy: true,
        alias: 'comment',
    },
    'template-string': {
        pattern: /`(?:\\[\s\S]|\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}|(?!\$\{)[^\\`])*`/,
        greedy: true,
        inside: {
            'template-punctuation': {
                pattern: /^`|`$/,
                alias: 'string',
            },
            interpolation: {
                pattern: /((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,
                lookbehind: true,
                inside: {
                    'interpolation-punctuation': {
                        pattern: /^\$\{|\}$/,
                        alias: 'punctuation',
                    },
                    rest: Prism__default.default.languages.javascript,
                },
            },
            string: /[\s\S]+/,
        },
    },
    'string-property': {
        pattern: /((?:^|[,{])[ \t]*)(["'])(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2(?=\s*:)/m,
        lookbehind: true,
        greedy: true,
        alias: 'property',
    },
});
Prism__default.default.languages.insertBefore('javascript', 'operator', {
    'literal-property': {
        pattern: /((?:^|[,{])[ \t]*)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/m,
        lookbehind: true,
        alias: 'property',
    },
});
if (Prism__default.default.languages.markup) {
    const markup = Prism__default.default.languages.markup;
    markup.tag.addInlined('script', 'javascript');
    markup.tag.addAttribute(/on(?:abort|blur|change|click|composition(?:end|start|update)|dblclick|error|focus(?:in|out)?|key(?:down|up)|load|mouse(?:down|enter|leave|move|out|over|up)|reset|resize|scroll|select|slotchange|submit|unload|wheel)/
        .source, 'javascript');
}
Prism__default.default.languages.js = Prism__default.default.languages.javascript;

Prism__default.default.languages.json = {
    property: {
        pattern: /(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?=\s*:)/,
        lookbehind: true,
        greedy: true,
    },
    string: {
        pattern: /(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?!\s*:)/,
        lookbehind: true,
        greedy: true,
    },
    comment: {
        pattern: /\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,
        greedy: true,
    },
    number: /-?\b\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i,
    punctuation: /[{}[\],]/,
    operator: /:/,
    boolean: /\b(?:false|true)\b/,
    null: {
        pattern: /\bnull\b/,
        alias: 'keyword',
    },
};
Prism__default.default.languages.webmanifest = Prism__default.default.languages.json;

const javascript = Prism__default.default.util.clone(Prism__default.default.languages.javascript);
const space = /(?:\s|\/\/.*(?!.)|\/\*(?:[^*]|\*(?!\/))\*\/)/.source;
const braces = /(?:\{(?:\{(?:\{[^{}]*\}|[^{}])*\}|[^{}])*\})/.source;
let spread = /(?:\{<S>*\.{3}(?:[^{}]|<BRACES>)*\})/.source;
function re(source, flags) {
    const resolvedSource = source
        .replace(/<S>/g, () => space)
        .replace(/<BRACES>/g, () => braces)
        .replace(/<SPREAD>/g, () => spread);
    return RegExp(resolvedSource, flags);
}
spread = re(spread).source;
Prism__default.default.languages.jsx = Prism__default.default.languages.extend('markup', javascript);
const jsx = Prism__default.default.languages.jsx;
jsx.tag.pattern = re(/<\/?(?:[\w.:-]+(?:<S>+(?:[\w.:$-]+(?:=(?:"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*'|[^\s{'"/>=]+|<BRACES>))?|<SPREAD>))*<S>*\/?)?>/
    .source);
jsx.tag.inside['tag'].pattern = /^<\/?[^\s>/]*/;
jsx.tag.inside['attr-value'].pattern =
    /=(?!\{)(?:"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*'|[^\s'">]+)/;
jsx.tag.inside['tag'].inside['class-name'] = /^[A-Z]\w*(?:\.[A-Z]\w*)*$/;
jsx.tag.inside['comment'] = javascript['comment'];
Prism__default.default.languages.insertBefore('inside', 'attr-name', {
    spread: {
        pattern: re(/<SPREAD>/.source),
        inside: Prism__default.default.languages.jsx,
    },
}, jsx.tag);
Prism__default.default.languages.insertBefore('inside', 'special-attr', {
    script: {
        pattern: re(/=<BRACES>/.source),
        alias: 'language-javascript',
        inside: {
            'script-punctuation': {
                pattern: /^=(?=\{)/,
                alias: 'punctuation',
            },
            rest: Prism__default.default.languages.jsx,
        },
    },
}, jsx.tag);
const stringifyToken = function (token) {
    if (!token) {
        return '';
    }
    if (typeof token === 'string') {
        return token;
    }
    if (typeof token.content === 'string') {
        return token.content;
    }
    return token.content.map(stringifyToken).join('');
};
const walkTokens = function (tokens) {
    const openedTags = [];
    for (let i = 0; i < tokens.length; i++) {
        const token = tokens[i];
        let notTagNorBrace = false;
        if (typeof token !== 'string') {
            const tokenContent = token.content;
            if (token.type === 'tag' && tokenContent[0] && tokenContent[0].type === 'tag') {
                if (tokenContent[0].content[0].content === '</') {
                    if (openedTags.length > 0 &&
                        openedTags[openedTags.length - 1].tagName === stringifyToken(tokenContent[0].content[1])) {
                        openedTags.pop();
                    }
                }
                else {
                    if (tokenContent[tokenContent.length - 1].content === '/>') ;
                    else {
                        openedTags.push({
                            tagName: stringifyToken(tokenContent[0].content[1]),
                            openedBraces: 0,
                        });
                    }
                }
            }
            else if (openedTags.length > 0 && token.type === 'punctuation' && token.content === '{') {
                openedTags[openedTags.length - 1].openedBraces += 1;
            }
            else if (openedTags.length > 0 &&
                openedTags[openedTags.length - 1].openedBraces > 0 &&
                token.type === 'punctuation' &&
                token.content === '}') {
                openedTags[openedTags.length - 1].openedBraces -= 1;
            }
            else {
                notTagNorBrace = true;
            }
        }
        if (notTagNorBrace || typeof token === 'string') {
            if (openedTags.length > 0 && openedTags[openedTags.length - 1].openedBraces === 0) {
                let plainText = stringifyToken(token);
                if (i < tokens.length - 1 &&
                    (typeof tokens[i + 1] === 'string' || tokens[i + 1].type === 'plain-text')) {
                    plainText += stringifyToken(tokens[i + 1]);
                    tokens.splice(i + 1, 1);
                }
                if (i > 0 &&
                    (typeof tokens[i - 1] === 'string' || tokens[i - 1].type === 'plain-text')) {
                    plainText = stringifyToken(tokens[i - 1]) + plainText;
                    tokens.splice(i - 1, 1);
                    i -= 1;
                }
                tokens[i] = new Prism__default.default.Token('plain-text', plainText, undefined, plainText);
            }
        }
        if (typeof token !== 'string') {
            if (token.content && typeof token.content !== 'string') {
                walkTokens(token.content);
            }
        }
    }
};
Prism__default.default.hooks.add('after-tokenize', function (env) {
    if (env.language !== 'jsx' && env.language !== 'tsx') {
        return;
    }
    walkTokens(env.tokens);
});

Prism__default.default.languages.makefile = {
    comment: {
        pattern: /(^|[^\\])#(?:\\(?:\r\n|[\s\S])|[^\\\r\n])*/,
        lookbehind: true,
    },
    string: {
        pattern: /(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,
        greedy: true,
    },
    'builtin-target': {
        pattern: /\.[A-Z][^:#=\s]+(?=\s*:(?!=))/,
        alias: 'builtin',
    },
    target: {
        pattern: /^(?:[^:=\s]|[ \t]+(?![\s:]))+(?=\s*:(?!=))/m,
        alias: 'symbol',
        inside: {
            variable: /\$+(?:(?!\$)[^(){}:#=\s]+|(?=[({]))/,
        },
    },
    variable: /\$+(?:(?!\$)[^(){}:#=\s]+|\([@*%<^+?][DF]\)|(?=[({]))/,
    keyword: /-include\b|\b(?:define|else|endef|endif|export|ifn?def|ifn?eq|include|override|private|sinclude|undefine|unexport|vpath)\b/,
    function: {
        pattern: /(\()(?:abspath|addsuffix|and|basename|call|dir|error|eval|file|filter(?:-out)?|findstring|firstword|flavor|foreach|guile|if|info|join|lastword|load|notdir|or|origin|patsubst|realpath|shell|sort|strip|subst|suffix|value|warning|wildcard|word(?:list|s)?)(?=[ \t])/,
        lookbehind: true,
    },
    operator: /(?:::|[?:+!])?=|[|@]/,
    punctuation: /[:;(){}]/,
};

const inner = /(?:\\.|[^\\\n\r]|(?:\n|\r\n?)(?![\r\n]))/.source;
function createInline(pattern) {
    const resolvedPattern = pattern.replace(/<inner>/g, function () {
        return inner;
    });
    return RegExp(/((?:^|[^\\])(?:\\{2})*)/.source + '(?:' + resolvedPattern + ')');
}
const tableCell = /(?:\\.|``(?:[^`\r\n]|`(?!`))+``|`[^`\r\n]+`|[^\\|\r\n`])+/.source;
const tableRow = /\|?__(?:\|__)+\|?(?:(?:\n|\r\n?)|(?![\s\S]))/.source.replace(/__/g, function () {
    return tableCell;
});
const tableLine = /\|?[ \t]*:?-{3,}:?[ \t]*(?:\|[ \t]*:?-{3,}:?[ \t]*)+\|?(?:\n|\r\n?)/.source;
Prism__default.default.languages.markdown = Prism__default.default.languages.extend('markup', {});
Prism__default.default.languages.insertBefore('markdown', 'prolog', {
    'front-matter-block': {
        pattern: /(^(?:\s*[\r\n])?)---(?!.)[\s\S]*?[\r\n]---(?!.)/,
        lookbehind: true,
        greedy: true,
        inside: {
            punctuation: /^---|---$/,
            'front-matter': {
                pattern: /\S+(?:\s+\S+)*/,
                alias: ['yaml', 'language-yaml'],
                inside: Prism__default.default.languages.yaml,
            },
        },
    },
    blockquote: {
        pattern: /^>(?:[\t ]*>)*/m,
        alias: 'punctuation',
    },
    table: {
        pattern: RegExp('^' + tableRow + tableLine + '(?:' + tableRow + ')*', 'm'),
        inside: {
            'table-data-rows': {
                pattern: RegExp('^(' + tableRow + tableLine + ')(?:' + tableRow + ')*$'),
                lookbehind: true,
                inside: {
                    'table-data': {
                        pattern: RegExp(tableCell),
                        inside: Prism__default.default.languages.markdown,
                    },
                    punctuation: /\|/,
                },
            },
            'table-line': {
                pattern: RegExp('^(' + tableRow + ')' + tableLine + '$'),
                lookbehind: true,
                inside: {
                    punctuation: /\||:?-{3,}:?/,
                },
            },
            'table-header-row': {
                pattern: RegExp('^' + tableRow + '$'),
                inside: {
                    'table-header': {
                        pattern: RegExp(tableCell),
                        alias: 'important',
                        inside: Prism__default.default.languages.markdown,
                    },
                    punctuation: /\|/,
                },
            },
        },
    },
    code: [
        {
            pattern: /((?:^|\n)[ \t]*\n|(?:^|\r\n?)[ \t]*\r\n?)(?: {4}|\t).+(?:(?:\n|\r\n?)(?: {4}|\t).+)*/,
            lookbehind: true,
            alias: 'keyword',
        },
        {
            pattern: /^```[\s\S]*?^```$/m,
            greedy: true,
            inside: {
                'code-block': {
                    pattern: /^(```.*(?:\n|\r\n?))[\s\S]+?(?=(?:\n|\r\n?)^```$)/m,
                    lookbehind: true,
                },
                'code-language': {
                    pattern: /^(```).+/,
                    lookbehind: true,
                },
                punctuation: /```/,
            },
        },
    ],
    title: [
        {
            pattern: /\S.*(?:\n|\r\n?)(?:==+|--+)(?=[ \t]*$)/m,
            alias: 'important',
            inside: {
                punctuation: /==+$|--+$/,
            },
        },
        {
            pattern: /(^\s*)#.+/m,
            lookbehind: true,
            alias: 'important',
            inside: {
                punctuation: /^#+|#+$/,
            },
        },
    ],
    hr: {
        pattern: /(^\s*)([*-])(?:[\t ]*\2){2,}(?=\s*$)/m,
        lookbehind: true,
        alias: 'punctuation',
    },
    list: {
        pattern: /(^\s*)(?:[*+-]|\d+\.)(?=[\t ].)/m,
        lookbehind: true,
        alias: 'punctuation',
    },
    'url-reference': {
        pattern: /!?\[[^\]]+\]:[\t ]+(?:\S+|<(?:\\.|[^>\\])+>)(?:[\t ]+(?:"(?:\\.|[^"\\])*"|'(?:\\.|[^'\\])*'|\((?:\\.|[^)\\])*\)))?/,
        inside: {
            variable: {
                pattern: /^(!?\[)[^\]]+/,
                lookbehind: true,
            },
            string: /(?:"(?:\\.|[^"\\])*"|'(?:\\.|[^'\\])*'|\((?:\\.|[^)\\])*\))$/,
            punctuation: /^[[\]!:]|[<>]/,
        },
        alias: 'url',
    },
    bold: {
        pattern: createInline(/\b__(?:(?!_)<inner>|_(?:(?!_)<inner>)+_)+__\b|\*\*(?:(?!\*)<inner>|\*(?:(?!\*)<inner>)+\*)+\*\*/
            .source),
        lookbehind: true,
        greedy: true,
        inside: {
            content: {
                pattern: /(^..)[\s\S]+(?=..$)/,
                lookbehind: true,
                inside: {},
            },
            punctuation: /\*\*|__/,
        },
    },
    italic: {
        pattern: createInline(/\b_(?:(?!_)<inner>|__(?:(?!_)<inner>)+__)+_\b|\*(?:(?!\*)<inner>|\*\*(?:(?!\*)<inner>)+\*\*)+\*/
            .source),
        lookbehind: true,
        greedy: true,
        inside: {
            content: {
                pattern: /(^.)[\s\S]+(?=.$)/,
                lookbehind: true,
                inside: {},
            },
            punctuation: /[*_]/,
        },
    },
    strike: {
        pattern: createInline(/(~~?)(?:(?!~)<inner>)+\2/.source),
        lookbehind: true,
        greedy: true,
        inside: {
            content: {
                pattern: /(^~~?)[\s\S]+(?=\1$)/,
                lookbehind: true,
                inside: {},
            },
            punctuation: /~~?/,
        },
    },
    'code-snippet': {
        pattern: /(^|[^\\`])(?:``[^`\r\n]+(?:`[^`\r\n]+)*``(?!`)|`[^`\r\n]+`(?!`))/,
        lookbehind: true,
        greedy: true,
        alias: ['code', 'keyword'],
    },
    url: {
        pattern: createInline(/!?\[(?:(?!\])<inner>)+\](?:\([^\s)]+(?:[\t ]+"(?:\\.|[^"\\])*")?\)|[ \t]?\[(?:(?!\])<inner>)+\])/
            .source),
        lookbehind: true,
        greedy: true,
        inside: {
            operator: /^!/,
            content: {
                pattern: /(^\[)[^\]]+(?=\])/,
                lookbehind: true,
                inside: {},
            },
            variable: {
                pattern: /(^\][ \t]?\[)[^\]]+(?=\]$)/,
                lookbehind: true,
            },
            url: {
                pattern: /(^\]\()[^\s)]+/,
                lookbehind: true,
            },
            string: {
                pattern: /(^[ \t]+)"(?:\\.|[^"\\])*"(?=\)$)/,
                lookbehind: true,
            },
        },
    },
});
['url', 'bold', 'italic', 'strike'].forEach(function (token) {
    ['url', 'bold', 'italic', 'strike', 'code-snippet'].forEach(function (inside) {
        if (token !== inside) {
            const markdown = Prism__default.default.languages.markdown;
            markdown[token].inside.content.inside[inside] = markdown[inside];
        }
    });
});
Prism__default.default.hooks.add('after-tokenize', function (env) {
    if (env.language !== 'markdown' && env.language !== 'md') {
        return;
    }
    function walkTokens(tokens) {
        if (!tokens || typeof tokens === 'string') {
            return;
        }
        for (let i = 0, l = tokens.length; i < l; i++) {
            const token = tokens[i];
            if (token.type !== 'code') {
                walkTokens(token.content);
                continue;
            }
            const codeLang = token.content[1];
            const codeBlock = token.content[3];
            if (codeLang &&
                codeBlock &&
                codeLang.type === 'code-language' &&
                codeBlock.type === 'code-block' &&
                typeof codeLang.content === 'string') {
                let lang = codeLang.content.replace(/\b#/g, 'sharp').replace(/\b\+\+/g, 'pp');
                lang = (/[a-z][\w-]*/i.exec(lang) || [''])[0].toLowerCase();
                const alias = 'language-' + lang;
                if (!codeBlock.alias) {
                    codeBlock.alias = [alias];
                }
                else if (typeof codeBlock.alias === 'string') {
                    codeBlock.alias = [codeBlock.alias, alias];
                }
                else {
                    codeBlock.alias.push(alias);
                }
            }
        }
    }
    walkTokens(env.tokens);
});
Prism__default.default.hooks.add('wrap', function (env) {
    if (env.type !== 'code-block') {
        return;
    }
    let codeLang = '';
    for (let i = 0, l = env.classes.length; i < l; i++) {
        const cls = env.classes[i];
        const match = /language-(.+)/.exec(cls);
        if (match) {
            codeLang = match[1];
            break;
        }
    }
    const grammar = Prism__default.default.languages[codeLang];
    if (!grammar) {
        if (codeLang && codeLang !== 'none' && Prism__default.default.plugins.autoloader) {
            const id = 'md-' + new Date().valueOf() + '-' + Math.floor(Math.random() * 1e16);
            env.attributes['id'] = id;
            Prism__default.default.plugins.autoloader.loadLanguages(codeLang, function () {
                const ele = document.getElementById(id);
                if (ele) {
                    ele.innerHTML = Prism__default.default.highlight(ele.textContent, Prism__default.default.languages[codeLang], codeLang);
                }
            });
        }
    }
    else {
        env.content = Prism__default.default.highlight(textContent(env.content), grammar, codeLang);
    }
});
const tagPattern = RegExp(Prism__default.default.languages.markup.tag.pattern.source, 'gi');
const KNOWN_ENTITY_NAMES = {
    amp: '&',
    lt: '<',
    gt: '>',
    quot: '"',
};
const fromCodePoint = String.fromCodePoint || String.fromCharCode;
function textContent(html) {
    let text = html.replace(tagPattern, '');
    text = text.replace(/&(\w{1,8}|#x?[\da-f]{1,8});/gi, function (m, code) {
        code = code.toLowerCase();
        if (code[0] === '#') {
            let value;
            if (code[1] === 'x') {
                value = parseInt(code.slice(2), 16);
            }
            else {
                value = Number(code.slice(1));
            }
            return fromCodePoint(value);
        }
        else {
            const known = KNOWN_ENTITY_NAMES[code];
            if (known) {
                return known;
            }
            return m;
        }
    });
    return text;
}
Prism__default.default.languages.md = Prism__default.default.languages.markdown;

Prism__default.default.languages.python = {
    comment: {
        pattern: /(^|[^\\])#.*/,
        lookbehind: true,
        greedy: true,
    },
    'string-interpolation': {
        pattern: /(?:f|fr|rf)(?:("""|''')[\s\S]*?\1|("|')(?:\\.|(?!\2)[^\\\r\n])*\2)/i,
        greedy: true,
        inside: {
            interpolation: {
                pattern: /((?:^|[^{])(?:\{\{)*)\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}])+\})+\})+\}/,
                lookbehind: true,
                inside: {
                    'format-spec': {
                        pattern: /(:)[^:(){}]+(?=\}$)/,
                        lookbehind: true,
                    },
                    'conversion-option': {
                        pattern: /![sra](?=[:}]$)/,
                        alias: 'punctuation',
                    },
                    rest: null,
                },
            },
            string: /[\s\S]+/,
        },
    },
    'triple-quoted-string': {
        pattern: /(?:[rub]|br|rb)?("""|''')[\s\S]*?\1/i,
        greedy: true,
        alias: 'string',
    },
    string: {
        pattern: /(?:[rub]|br|rb)?("|')(?:\\.|(?!\1)[^\\\r\n])*\1/i,
        greedy: true,
    },
    function: {
        pattern: /((?:^|\s)def[ \t]+)[a-zA-Z_]\w*(?=\s*\()/g,
        lookbehind: true,
    },
    'class-name': {
        pattern: /(\bclass\s+)\w+/i,
        lookbehind: true,
    },
    decorator: {
        pattern: /(^[\t ]*)@\w+(?:\.\w+)*/m,
        lookbehind: true,
        alias: ['annotation', 'punctuation'],
        inside: {
            punctuation: /\./,
        },
    },
    keyword: /\b(?:_(?=\s*:)|and|as|assert|async|await|break|case|class|continue|def|del|elif|else|except|exec|finally|for|from|global|if|import|in|is|lambda|match|nonlocal|not|or|pass|print|raise|return|try|while|with|yield)\b/,
    builtin: /\b(?:__import__|abs|all|any|apply|ascii|basestring|bin|bool|buffer|bytearray|bytes|callable|chr|classmethod|cmp|coerce|compile|complex|delattr|dict|dir|divmod|enumerate|eval|execfile|file|filter|float|format|frozenset|getattr|globals|hasattr|hash|help|hex|id|input|int|intern|isinstance|issubclass|iter|len|list|locals|long|map|max|memoryview|min|next|object|oct|open|ord|pow|property|range|raw_input|reduce|reload|repr|reversed|round|set|setattr|slice|sorted|staticmethod|str|sum|super|tuple|type|unichr|unicode|vars|xrange|zip)\b/,
    boolean: /\b(?:False|None|True)\b/,
    number: /\b0(?:b(?:_?[01])+|o(?:_?[0-7])+|x(?:_?[a-f0-9])+)\b|(?:\b\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\B\.\d+(?:_\d+)*)(?:e[+-]?\d+(?:_\d+)*)?j?(?!\w)/i,
    operator: /[-+%=]=?|!=|:=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/,
    punctuation: /[{}[\];(),.:]/,
};
Prism__default.default.languages.python['string-interpolation'].inside['interpolation'].inside.rest =
    Prism__default.default.languages.python;
Prism__default.default.languages.py = Prism__default.default.languages.python;

Prism__default.default.languages.scss = Prism__default.default.languages.extend('css', {
    comment: {
        pattern: /(^|[^\\])(?:\/\*[\s\S]*?\*\/|\/\/.*)/,
        lookbehind: true,
    },
    atrule: {
        pattern: /@[\w-](?:\([^()]+\)|[^()\s]|\s+(?!\s))*?(?=\s+[{;])/,
        inside: {
            rule: /@[\w-]+/,
        },
    },
    url: /(?:[-a-z]+-)?url(?=\()/i,
    selector: {
        pattern: /(?=\S)[^@;{}()]?(?:[^@;{}()\s]|\s+(?!\s)|#\{\$[-\w]+\})+(?=\s*\{(?:\}|\s|[^}][^:{}]*[:{][^}]))/,
        inside: {
            parent: {
                pattern: /&/,
                alias: 'important',
            },
            placeholder: /%[-\w]+/,
            variable: /\$[-\w]+|#\{\$[-\w]+\}/,
        },
    },
    property: {
        pattern: /(?:[-\w]|\$[-\w]|#\{\$[-\w]+\})+(?=\s*:)/,
        inside: {
            variable: /\$[-\w]+|#\{\$[-\w]+\}/,
        },
    },
});
Prism__default.default.languages.insertBefore('scss', 'atrule', {
    keyword: [
        /@(?:content|debug|each|else(?: if)?|extend|for|forward|function|if|import|include|mixin|return|use|warn|while)\b/i,
        {
            pattern: /( )(?:from|through)(?= )/,
            lookbehind: true,
        },
    ],
});
Prism__default.default.languages.insertBefore('scss', 'important', {
    variable: /\$[-\w]+|#\{\$[-\w]+\}/,
});
Prism__default.default.languages.insertBefore('scss', 'function', {
    'module-modifier': {
        pattern: /\b(?:as|hide|show|with)\b/i,
        alias: 'keyword',
    },
    placeholder: {
        pattern: /%[-\w]+/,
        alias: 'selector',
    },
    statement: {
        pattern: /\B!(?:default|optional)\b/i,
        alias: 'keyword',
    },
    boolean: /\b(?:false|true)\b/,
    null: {
        pattern: /\bnull\b/,
        alias: 'keyword',
    },
    operator: {
        pattern: /(\s)(?:[-+*/%]|[=!]=|<=?|>=?|and|not|or)(?=\s)/,
        lookbehind: true,
    },
});
Prism__default.default.languages.scss['atrule'].inside.rest = Prism__default.default.languages.scss;

Prism__default.default.languages.sass = Prism__default.default.languages.extend('css', {
    comment: {
        pattern: /^([ \t]*)\/[/*].*(?:(?:\r?\n|\r)\1[ \t].+)*/m,
        lookbehind: true,
        greedy: true,
    },
});
Prism__default.default.languages.insertBefore('sass', 'atrule', {
    'atrule-line': {
        pattern: /^(?:[ \t]*)[@+=].+/m,
        greedy: true,
        inside: {
            atrule: /(?:@[\w-]+|[+=])/,
        },
    },
});
delete Prism__default.default.languages.sass.atrule;
const variable = /\$[-\w]+|#\{\$[-\w]+\}/;
const operator = [
    /[+*/%]|[=!]=|<=?|>=?|\b(?:and|not|or)\b/,
    {
        pattern: /(\s)-(?=\s)/,
        lookbehind: true,
    },
];
Prism__default.default.languages.insertBefore('sass', 'property', {
    'variable-line': {
        pattern: /^[ \t]*\$.+/m,
        greedy: true,
        inside: {
            punctuation: /:/,
            variable: variable,
            operator: operator,
        },
    },
    'property-line': {
        pattern: /^[ \t]*(?:[^:\s]+ *:.*|:[^:\s].*)/m,
        greedy: true,
        inside: {
            property: [
                /[^:\s]+(?=\s*:)/,
                {
                    pattern: /(:)[^:\s]+/,
                    lookbehind: true,
                },
            ],
            punctuation: /:/,
            variable: variable,
            operator: operator,
            important: Prism__default.default.languages.sass.important,
        },
    },
});
delete Prism__default.default.languages.sass.property;
delete Prism__default.default.languages.sass.important;
Prism__default.default.languages.insertBefore('sass', 'punctuation', {
    selector: {
        pattern: /^([ \t]*)\S(?:,[^,\r\n]+|[^,\r\n]*)(?:,[^,\r\n]+)*(?:,(?:\r?\n|\r)\1[ \t]+\S(?:,[^,\r\n]+|[^,\r\n]*)(?:,[^,\r\n]+)*)*/m,
        lookbehind: true,
        greedy: true,
    },
});

Prism__default.default.languages.sql = {
    comment: {
        pattern: /(^|[^\\])(?:\/\*[\s\S]*?\*\/|(?:--|\/\/|#).*)/,
        lookbehind: true,
    },
    variable: [
        {
            pattern: /@(["'`])(?:\\[\s\S]|(?!\1)[^\\])+\1/,
            greedy: true,
        },
        /@[\w.$]+/,
    ],
    string: {
        pattern: /(^|[^@\\])("|')(?:\\[\s\S]|(?!\2)[^\\]|\2\2)*\2/,
        greedy: true,
        lookbehind: true,
    },
    identifier: {
        pattern: /(^|[^@\\])`(?:\\[\s\S]|[^`\\]|``)*`/,
        greedy: true,
        lookbehind: true,
        inside: {
            punctuation: /^`|`$/,
        },
    },
    function: /\b(?:AVG|COUNT|FIRST|FORMAT|LAST|LCASE|LEN|MAX|MID|MIN|MOD|NOW|ROUND|SUM|UCASE)(?=\s*\()/i,
    keyword: /\b(?:ACTION|ADD|AFTER|ALGORITHM|ALL|ALTER|ANALYZE|ANY|APPLY|AS|ASC|AUTHORIZATION|AUTO_INCREMENT|BACKUP|BDB|BEGIN|BERKELEYDB|BIGINT|BINARY|BIT|BLOB|BOOL|BOOLEAN|BREAK|BROWSE|BTREE|BULK|BY|CALL|CASCADED?|CASE|CHAIN|CHAR(?:ACTER|SET)?|CHECK(?:POINT)?|CLOSE|CLUSTERED|COALESCE|COLLATE|COLUMNS?|COMMENT|COMMIT(?:TED)?|COMPUTE|CONNECT|CONSISTENT|CONSTRAINT|CONTAINS(?:TABLE)?|CONTINUE|CONVERT|CREATE|CROSS|CURRENT(?:_DATE|_TIME|_TIMESTAMP|_USER)?|CURSOR|CYCLE|DATA(?:BASES?)?|DATE(?:TIME)?|DAY|DBCC|DEALLOCATE|DEC|DECIMAL|DECLARE|DEFAULT|DEFINER|DELAYED|DELETE|DELIMITERS?|DENY|DESC|DESCRIBE|DETERMINISTIC|DISABLE|DISCARD|DISK|DISTINCT|DISTINCTROW|DISTRIBUTED|DO|DOUBLE|DROP|DUMMY|DUMP(?:FILE)?|DUPLICATE|ELSE(?:IF)?|ENABLE|ENCLOSED|END|ENGINE|ENUM|ERRLVL|ERRORS|ESCAPED?|EXCEPT|EXEC(?:UTE)?|EXISTS|EXIT|EXPLAIN|EXTENDED|FETCH|FIELDS|FILE|FILLFACTOR|FIRST|FIXED|FLOAT|FOLLOWING|FOR(?: EACH ROW)?|FORCE|FOREIGN|FREETEXT(?:TABLE)?|FROM|FULL|FUNCTION|GEOMETRY(?:COLLECTION)?|GLOBAL|GOTO|GRANT|GROUP|HANDLER|HASH|HAVING|HOLDLOCK|HOUR|IDENTITY(?:COL|_INSERT)?|IF|IGNORE|IMPORT|INDEX|INFILE|INNER|INNODB|INOUT|INSERT|INT|INTEGER|INTERSECT|INTERVAL|INTO|INVOKER|ISOLATION|ITERATE|JOIN|KEYS?|KILL|LANGUAGE|LAST|LEAVE|LEFT|LEVEL|LIMIT|LINENO|LINES|LINESTRING|LOAD|LOCAL|LOCK|LONG(?:BLOB|TEXT)|LOOP|MATCH(?:ED)?|MEDIUM(?:BLOB|INT|TEXT)|MERGE|MIDDLEINT|MINUTE|MODE|MODIFIES|MODIFY|MONTH|MULTI(?:LINESTRING|POINT|POLYGON)|NATIONAL|NATURAL|NCHAR|NEXT|NO|NONCLUSTERED|NULLIF|NUMERIC|OFF?|OFFSETS?|ON|OPEN(?:DATASOURCE|QUERY|ROWSET)?|OPTIMIZE|OPTION(?:ALLY)?|ORDER|OUT(?:ER|FILE)?|OVER|PARTIAL|PARTITION|PERCENT|PIVOT|PLAN|POINT|POLYGON|PRECEDING|PRECISION|PREPARE|PREV|PRIMARY|PRINT|PRIVILEGES|PROC(?:EDURE)?|PUBLIC|PURGE|QUICK|RAISERROR|READS?|REAL|RECONFIGURE|REFERENCES|RELEASE|RENAME|REPEAT(?:ABLE)?|REPLACE|REPLICATION|REQUIRE|RESIGNAL|RESTORE|RESTRICT|RETURN(?:ING|S)?|REVOKE|RIGHT|ROLLBACK|ROUTINE|ROW(?:COUNT|GUIDCOL|S)?|RTREE|RULE|SAVE(?:POINT)?|SCHEMA|SECOND|SELECT|SERIAL(?:IZABLE)?|SESSION(?:_USER)?|SET(?:USER)?|SHARE|SHOW|SHUTDOWN|SIMPLE|SMALLINT|SNAPSHOT|SOME|SONAME|SQL|START(?:ING)?|STATISTICS|STATUS|STRIPED|SYSTEM_USER|TABLES?|TABLESPACE|TEMP(?:ORARY|TABLE)?|TERMINATED|TEXT(?:SIZE)?|THEN|TIME(?:STAMP)?|TINY(?:BLOB|INT|TEXT)|TOP?|TRAN(?:SACTIONS?)?|TRIGGER|TRUNCATE|TSEQUAL|TYPES?|UNBOUNDED|UNCOMMITTED|UNDEFINED|UNION|UNIQUE|UNLOCK|UNPIVOT|UNSIGNED|UPDATE(?:TEXT)?|USAGE|USE|USER|USING|VALUES?|VAR(?:BINARY|CHAR|CHARACTER|YING)|VIEW|WAITFOR|WARNINGS|WHEN|WHERE|WHILE|WITH(?: ROLLUP|IN)?|WORK|WRITE(?:TEXT)?|YEAR)\b/i,
    boolean: /\b(?:FALSE|NULL|TRUE)\b/i,
    number: /\b0x[\da-f]+\b|\b\d+(?:\.\d*)?|\B\.\d+\b/i,
    operator: /[-+*/=%^~]|&&?|\|\|?|!=?|<(?:=>?|<|>)?|>[>=]?|\b(?:AND|BETWEEN|DIV|ILIKE|IN|IS|LIKE|NOT|OR|REGEXP|RLIKE|SOUNDS LIKE|XOR)\b/i,
    punctuation: /[;[\]()`,.]/,
};

const unit = {
    pattern: /(\b\d+)(?:%|[a-z]+)/,
    lookbehind: true,
};
const number = {
    pattern: /(^|[^\w.-])-?(?:\d+(?:\.\d+)?|\.\d+)/,
    lookbehind: true,
};
const inside = {
    comment: {
        pattern: /(^|[^\\])(?:\/\*[\s\S]*?\*\/|\/\/.*)/,
        lookbehind: true,
    },
    url: {
        pattern: /\burl\((["']?).*?\1\)/i,
        greedy: true,
    },
    string: {
        pattern: /("|')(?:(?!\1)[^\\\r\n]|\\(?:\r\n|[\s\S]))*\1/,
        greedy: true,
    },
    interpolation: null,
    func: null,
    important: /\B!(?:important|optional)\b/i,
    keyword: {
        pattern: /(^|\s+)(?:(?:else|for|if|return|unless)(?=\s|$)|@[\w-]+)/,
        lookbehind: true,
    },
    hexcode: /#[\da-f]{3,6}/i,
    color: [
        /\b(?:AliceBlue|AntiqueWhite|Aqua|Aquamarine|Azure|Beige|Bisque|Black|BlanchedAlmond|Blue|BlueViolet|Brown|BurlyWood|CadetBlue|Chartreuse|Chocolate|Coral|CornflowerBlue|Cornsilk|Crimson|Cyan|DarkBlue|DarkCyan|DarkGoldenRod|DarkGr[ae]y|DarkGreen|DarkKhaki|DarkMagenta|DarkOliveGreen|DarkOrange|DarkOrchid|DarkRed|DarkSalmon|DarkSeaGreen|DarkSlateBlue|DarkSlateGr[ae]y|DarkTurquoise|DarkViolet|DeepPink|DeepSkyBlue|DimGr[ae]y|DodgerBlue|FireBrick|FloralWhite|ForestGreen|Fuchsia|Gainsboro|GhostWhite|Gold|GoldenRod|Gr[ae]y|Green|GreenYellow|HoneyDew|HotPink|IndianRed|Indigo|Ivory|Khaki|Lavender|LavenderBlush|LawnGreen|LemonChiffon|LightBlue|LightCoral|LightCyan|LightGoldenRodYellow|LightGr[ae]y|LightGreen|LightPink|LightSalmon|LightSeaGreen|LightSkyBlue|LightSlateGr[ae]y|LightSteelBlue|LightYellow|Lime|LimeGreen|Linen|Magenta|Maroon|MediumAquaMarine|MediumBlue|MediumOrchid|MediumPurple|MediumSeaGreen|MediumSlateBlue|MediumSpringGreen|MediumTurquoise|MediumVioletRed|MidnightBlue|MintCream|MistyRose|Moccasin|NavajoWhite|Navy|OldLace|Olive|OliveDrab|Orange|OrangeRed|Orchid|PaleGoldenRod|PaleGreen|PaleTurquoise|PaleVioletRed|PapayaWhip|PeachPuff|Peru|Pink|Plum|PowderBlue|Purple|Red|RosyBrown|RoyalBlue|SaddleBrown|Salmon|SandyBrown|SeaGreen|SeaShell|Sienna|Silver|SkyBlue|SlateBlue|SlateGr[ae]y|Snow|SpringGreen|SteelBlue|Tan|Teal|Thistle|Tomato|Transparent|Turquoise|Violet|Wheat|White|WhiteSmoke|Yellow|YellowGreen)\b/i,
        {
            pattern: /\b(?:hsl|rgb)\(\s*\d{1,3}\s*,\s*\d{1,3}%?\s*,\s*\d{1,3}%?\s*\)\B|\b(?:hsl|rgb)a\(\s*\d{1,3}\s*,\s*\d{1,3}%?\s*,\s*\d{1,3}%?\s*,\s*(?:0|0?\.\d+|1)\s*\)\B/i,
            inside: {
                unit: unit,
                number: number,
                function: /[\w-]+(?=\()/,
                punctuation: /[(),]/,
            },
        },
    ],
    entity: /\\[\da-f]{1,8}/i,
    unit: unit,
    boolean: /\b(?:false|true)\b/,
    operator: [
        /~|[+!/%<>?=]=?|[-:]=|\*[*=]?|\.{2,3}|&&|\|\||\B-\B|\b(?:and|in|is(?: a| defined| not|nt)?|not|or)\b/,
    ],
    number: number,
    punctuation: /[{}()[\];:,]/,
};
inside['interpolation'] = {
    pattern: /\{[^\r\n}:]+\}/,
    alias: 'variable',
    inside: {
        delimiter: {
            pattern: /^\{|\}$/,
            alias: 'punctuation',
        },
        rest: inside,
    },
};
inside['func'] = {
    pattern: /[\w-]+\([^)]*\).*/,
    inside: {
        function: /^[^(]+/,
        rest: inside,
    },
};
Prism__default.default.languages.stylus = {
    'atrule-declaration': {
        pattern: /(^[ \t]*)@.+/m,
        lookbehind: true,
        inside: {
            atrule: /^@[\w-]+/,
            rest: inside,
        },
    },
    'variable-declaration': {
        pattern: /(^[ \t]*)[\w$-]+\s*.?=[ \t]*(?:\{[^{}]*\}|\S.*|$)/m,
        lookbehind: true,
        inside: {
            variable: /^\S+/,
            rest: inside,
        },
    },
    statement: {
        pattern: /(^[ \t]*)(?:else|for|if|return|unless)[ \t].+/m,
        lookbehind: true,
        inside: {
            keyword: /^\S+/,
            rest: inside,
        },
    },
    'property-declaration': {
        pattern: /((?:^|\{)([ \t]*))(?:[\w-]|\{[^}\r\n]+\})+(?:\s*:\s*|[ \t]+)(?!\s)[^{\r\n]*(?:;|[^{\r\n,]$(?!(?:\r?\n|\r)(?:\{|\2[ \t])))/m,
        lookbehind: true,
        inside: {
            property: {
                pattern: /^[^\s:]+/,
                inside: {
                    interpolation: inside.interpolation,
                },
            },
            rest: inside,
        },
    },
    selector: {
        pattern: /(^[ \t]*)(?:(?=\S)(?:[^{}\r\n:()]|::?[\w-]+(?:\([^)\r\n]*\)|(?![\w-]))|\{[^}\r\n]+\})+)(?:(?:\r?\n|\r)(?:\1(?:(?=\S)(?:[^{}\r\n:()]|::?[\w-]+(?:\([^)\r\n]*\)|(?![\w-]))|\{[^}\r\n]+\})+)))*(?:,$|\{|(?=(?:\r?\n|\r)(?:\{|\1[ \t])))/m,
        lookbehind: true,
        inside: {
            interpolation: inside.interpolation,
            comment: inside.comment,
            punctuation: /[{},]/,
        },
    },
    func: inside.func,
    string: inside.string,
    comment: {
        pattern: /(^|[^\\])(?:\/\*[\s\S]*?\*\/|\/\/.*)/,
        lookbehind: true,
        greedy: true,
    },
    interpolation: inside.interpolation,
    punctuation: /[{}()[\];:.]/,
};

Prism__default.default.languages.typescript = Prism__default.default.languages.extend('javascript', {
    'class-name': {
        pattern: /(\b(?:class|extends|implements|instanceof|interface|new|type)\s+)(?!keyof\b)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?:\s*<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>)?/,
        lookbehind: true,
        greedy: true,
        inside: null,
    },
    builtin: /\b(?:Array|Function|Promise|any|boolean|console|never|number|string|symbol|unknown)\b/,
});
Prism__default.default.languages.typescript.keyword.push(/\b(?:abstract|declare|is|keyof|readonly|require)\b/, /\b(?:asserts|infer|interface|module|namespace|type)\b(?=\s*(?:[{_$a-zA-Z\xA0-\uFFFF]|$))/, /\btype\b(?=\s*(?:[{*]|$))/);
delete Prism__default.default.languages.typescript.parameter;
delete Prism__default.default.languages.typescript['literal-property'];
const typeInside = Prism__default.default.languages.extend('typescript', {});
delete typeInside['class-name'];
Prism__default.default.languages.typescript['class-name'].inside = typeInside;
Prism__default.default.languages.insertBefore('typescript', 'function', {
    decorator: {
        pattern: /@[$\w\xA0-\uFFFF]+/,
        inside: {
            at: {
                pattern: /^@/,
                alias: 'operator',
            },
            function: /^[\s\S]+/,
        },
    },
    'generic-function': {
        pattern: /#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>(?=\s*\()/,
        greedy: true,
        inside: {
            function: /^#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*/,
            generic: {
                pattern: /<[\s\S]+/,
                alias: 'class-name',
                inside: typeInside,
            },
        },
    },
});
Prism__default.default.languages.ts = Prism__default.default.languages.typescript;

const typescript = Prism__default.default.util.clone(Prism__default.default.languages.typescript);
Prism__default.default.languages.tsx = Prism__default.default.languages.extend('jsx', typescript);
delete Prism__default.default.languages.tsx.parameter;
delete Prism__default.default.languages.tsx['literal-property'];
const tag$1 = Prism__default.default.languages.tsx.tag;
tag$1.pattern = RegExp(/(^|[^\w$]|(?=<\/))/.source + '(?:' + tag$1.pattern.source + ')', tag$1.pattern.flags);
tag$1.lookbehind = true;

Prism__default.default.languages['visual-basic'] = {
    comment: {
        pattern: /(?:['‘’]|REM\b)(?:[^\r\n_]|_(?:\r\n?|\n)?)*/i,
        inside: {
            keyword: /^REM/i,
        },
    },
    directive: {
        pattern: /#(?:Const|Else|ElseIf|End|ExternalChecksum|ExternalSource|If|Region)(?:\b_[ \t]*(?:\r\n?|\n)|.)+/i,
        alias: 'property',
        greedy: true,
    },
    string: {
        pattern: /\$?["“”](?:["“”]{2}|[^"“”])*["“”]C?/i,
        greedy: true,
    },
    date: {
        pattern: /#[ \t]*(?:\d+([/-])\d+\1\d+(?:[ \t]+(?:\d+[ \t]*(?:AM|PM)|\d+:\d+(?::\d+)?(?:[ \t]*(?:AM|PM))?))?|\d+[ \t]*(?:AM|PM)|\d+:\d+(?::\d+)?(?:[ \t]*(?:AM|PM))?)[ \t]*#/i,
        alias: 'number',
    },
    number: /(?:(?:\b\d+(?:\.\d+)?|\.\d+)(?:E[+-]?\d+)?|&[HO][\dA-F]+)(?:[FRD]|U?[ILS])?/i,
    boolean: /\b(?:False|Nothing|True)\b/i,
    keyword: /\b(?:AddHandler|AddressOf|Alias|And(?:Also)?|As|Boolean|ByRef|Byte|ByVal|Call|Case|Catch|C(?:Bool|Byte|Char|Date|Dbl|Dec|Int|Lng|Obj|SByte|Short|Sng|Str|Type|UInt|ULng|UShort)|Char|Class|Const|Continue|Currency|Date|Decimal|Declare|Default|Delegate|Dim|DirectCast|Do|Double|Each|Else(?:If)?|End(?:If)?|Enum|Erase|Error|Event|Exit|Finally|For|Friend|Function|Get(?:Type|XMLNamespace)?|Global|GoSub|GoTo|Handles|If|Implements|Imports|In|Inherits|Integer|Interface|Is|IsNot|Let|Lib|Like|Long|Loop|Me|Mod|Module|Must(?:Inherit|Override)|My(?:Base|Class)|Namespace|Narrowing|New|Next|Not(?:Inheritable|Overridable)?|Object|Of|On|Operator|Option(?:al)?|Or(?:Else)?|Out|Overloads|Overridable|Overrides|ParamArray|Partial|Private|Property|Protected|Public|RaiseEvent|ReadOnly|ReDim|RemoveHandler|Resume|Return|SByte|Select|Set|Shadows|Shared|short|Single|Static|Step|Stop|String|Structure|Sub|SyncLock|Then|Throw|To|Try|TryCast|Type|TypeOf|U(?:Integer|Long|Short)|Until|Using|Variant|Wend|When|While|Widening|With(?:Events)?|WriteOnly|Xor)\b/i,
    operator: /[+\-*/\\^<=>&#@$%!]|\b_(?=[ \t]*[\r\n])/,
    punctuation: /[{}().,:?]/,
};
Prism__default.default.languages.vb = Prism__default.default.languages['visual-basic'];
Prism__default.default.languages.vba = Prism__default.default.languages['visual-basic'];

Prism__default.default.languages.wasm = {
    comment: [
        /\(;[\s\S]*?;\)/,
        {
            pattern: /;;.*/,
            greedy: true,
        },
    ],
    string: {
        pattern: /"(?:\\[\s\S]|[^"\\])*"/,
        greedy: true,
    },
    keyword: [
        {
            pattern: /\b(?:align|offset)=/,
            inside: {
                operator: /=/,
            },
        },
        {
            pattern: /\b(?:(?:f32|f64|i32|i64)(?:\.(?:abs|add|and|ceil|clz|const|convert_[su]\/i(?:32|64)|copysign|ctz|demote\/f64|div(?:_[su])?|eqz?|extend_[su]\/i32|floor|ge(?:_[su])?|gt(?:_[su])?|le(?:_[su])?|load(?:(?:8|16|32)_[su])?|lt(?:_[su])?|max|min|mul|neg?|nearest|or|popcnt|promote\/f32|reinterpret\/[fi](?:32|64)|rem_[su]|rot[lr]|shl|shr_[su]|sqrt|store(?:8|16|32)?|sub|trunc(?:_[su]\/f(?:32|64))?|wrap\/i64|xor))?|memory\.(?:grow|size))\b/,
            inside: {
                punctuation: /\./,
            },
        },
        /\b(?:anyfunc|block|br(?:_if|_table)?|call(?:_indirect)?|data|drop|elem|else|end|export|func|get_(?:global|local)|global|if|import|local|loop|memory|module|mut|nop|offset|param|result|return|select|set_(?:global|local)|start|table|tee_local|then|type|unreachable)\b/,
    ],
    variable: /\$[\w!#$%&'*+\-./:<=>?@\\^`|~]+/,
    number: /[+-]?\b(?:\d(?:_?\d)*(?:\.\d(?:_?\d)*)?(?:[eE][+-]?\d(?:_?\d)*)?|0x[\da-fA-F](?:_?[\da-fA-F])*(?:\.[\da-fA-F](?:_?[\da-fA-D])*)?(?:[pP][+-]?\d(?:_?\d)*)?)\b|\binf\b|\bnan(?::0x[\da-fA-F](?:_?[\da-fA-D])*)?\b/,
    punctuation: /[()]/,
};

const anchorOrAlias = /[*&][^\s[\]{},]+/;
const tag = /!(?:<[\w\-%#;/?:@&=+$,.!~*'()[\]]+>|(?:[a-zA-Z\d-]*!)?[\w\-%#;/?:@&=+$.~*'()]+)?/;
const properties = '(?:' +
    tag.source +
    '(?:[ \t]+' +
    anchorOrAlias.source +
    ')?|' +
    anchorOrAlias.source +
    '(?:[ \t]+' +
    tag.source +
    ')?)';
const plainKey = /(?:[^\s\x00-\x08\x0e-\x1f!"#%&'*,\-:>?@[\]`{|}\x7f-\x84\x86-\x9f\ud800-\udfff\ufffe\uffff]|[?:-]<PLAIN>)(?:[ \t]*(?:(?![#:])<PLAIN>|:<PLAIN>))*/.source.replace(/<PLAIN>/g, () => /[^\s\x00-\x08\x0e-\x1f,[\]{}\x7f-\x84\x86-\x9f\ud800-\udfff\ufffe\uffff]/.source);
const string = /"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\\\r\n]|\\.)*'/.source;
function createValuePattern(value, flags0) {
    const flags = (flags0 || '').replace(/m/g, '') + 'm';
    const pattern = /([:\-,[{]\s*(?:\s<<prop>>[ \t]+)?)(?:<<value>>)(?=[ \t]*(?:$|,|\]|\}|(?:[\r\n]\s*)?#))/.source
        .replace(/<<prop>>/g, function () {
        return properties;
    })
        .replace(/<<value>>/g, function () {
        return value;
    });
    return RegExp(pattern, flags);
}
Prism__default.default.languages.yaml = {
    scalar: {
        pattern: RegExp(/([-:]\s*(?:\s<<prop>>[ \t]+)?[|>])[ \t]*(?:((?:\r?\n|\r)[ \t]+)\S[^\r\n]*(?:\2[^\r\n]+)*)/.source.replace(/<<prop>>/g, function () {
            return properties;
        })),
        lookbehind: true,
        alias: 'string',
    },
    comment: /#.*/,
    key: {
        pattern: RegExp(/((?:^|[:\-,[{\r\n?])[ \t]*(?:<<prop>>[ \t]+)?)<<key>>(?=\s*:\s)/.source
            .replace(/<<prop>>/g, function () {
            return properties;
        })
            .replace(/<<key>>/g, function () {
            return '(?:' + plainKey + '|' + string + ')';
        })),
        lookbehind: true,
        greedy: true,
        alias: 'atrule',
    },
    directive: {
        pattern: /(^[ \t]*)%.+/m,
        lookbehind: true,
        alias: 'important',
    },
    datetime: {
        pattern: createValuePattern(/\d{4}-\d\d?-\d\d?(?:[tT]|[ \t]+)\d\d?:\d{2}:\d{2}(?:\.\d*)?(?:[ \t]*(?:Z|[-+]\d\d?(?::\d{2})?))?|\d{4}-\d{2}-\d{2}|\d\d?:\d{2}(?::\d{2}(?:\.\d*)?)?/
            .source),
        lookbehind: true,
        alias: 'number',
    },
    boolean: {
        pattern: createValuePattern(/false|true/.source, 'i'),
        lookbehind: true,
        alias: 'important',
    },
    null: {
        pattern: createValuePattern(/null|~/.source, 'i'),
        lookbehind: true,
        alias: 'important',
    },
    string: {
        pattern: createValuePattern(string),
        lookbehind: true,
        greedy: true,
    },
    number: {
        pattern: createValuePattern(/[+-]?(?:0x[\da-f]+|0o[0-7]+|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?|\.inf|\.nan)/.source, 'i'),
        lookbehind: true,
    },
    tag: tag,
    important: anchorOrAlias,
    punctuation: /---|[:[\]{}\-,|>?]|\.\.\./,
};
Prism__default.default.languages.yml = Prism__default.default.languages.yaml;

const vscDarkTheme = {
    plain: {
        color: '#d4d4d4',
        backgroundColor: '#1e1e1e',
    },
    styles: [
        {
            types: ['prolog'],
            style: { color: 'rgb(0, 0, 128)' },
        },
        {
            types: ['comment', 'punctuation'],
            style: { color: 'rgb(106, 153, 85)' },
        },
        {
            types: ['builtin'],
            style: { color: 'rgb(79, 193, 255)' },
        },
        {
            types: ['number', 'variable', 'inserted'],
            style: { color: 'rgb(181, 206, 168)' },
        },
        {
            types: ['operator'],
            style: { color: 'rgb(212, 212, 212)' },
        },
        {
            types: ['constant'],
            style: { color: 'rgb(100, 102, 149)' },
        },
        {
            types: ['tag', 'changed', 'function', 'keyword'],
            style: { color: 'rgb(86, 156, 214)' },
        },
        {
            types: ['attr-name'],
            style: { color: 'rgb(156, 220, 254)' },
        },
        {
            types: ['deleted', 'string', 'attr-value'],
            style: { color: 'rgb(206, 145, 120)' },
        },
        {
            types: ['class-name'],
            style: { color: 'rgb(78, 201, 176)' },
        },
        {
            types: ['char'],
            style: { color: 'rgb(209, 105, 105)' },
        },
        {
            types: ['selector'],
            style: { color: 'rgb(215, 186, 125)' },
        },
        {
            types: ['tag'],
            languages: ['markup'],
            style: { color: 'rgb(86, 156, 214)' },
        },
        {
            types: ['punctuation'],
            languages: ['markup'],
            style: { color: '#808080' },
        },
    ],
};

const vscLightTheme = {
    plain: {
        color: '#000000',
        backgroundColor: '#ffffff',
    },
    styles: [
        {
            types: ['comment'],
            style: { color: 'rgb(0, 128, 0)' },
        },
        {
            types: ['builtin'],
            style: { color: 'rgb(0, 112, 193)' },
        },
        {
            types: ['number', 'variable', 'inserted'],
            style: { color: 'rgb(9, 134, 88)' },
        },
        {
            types: ['operator'],
            style: {
                color: 'rgb(0, 0, 0)',
            },
        },
        {
            types: ['constant', 'char'],
            style: { color: 'rgb(129, 31, 63)' },
        },
        {
            types: ['tag'],
            style: { color: 'rgb(128, 0, 0)' },
        },
        {
            types: ['attr-name'],
            style: { color: 'rgb(255, 0, 0)' },
        },
        {
            types: ['deleted', 'string'],
            style: { color: 'rgb(163, 21, 21)' },
        },
        {
            types: ['changed', 'punctuation'],
            style: { color: 'rgb(4, 81, 165)' },
        },
        {
            types: ['function', 'keyword'],
            style: { color: 'rgb(0, 0, 255)' },
        },
        {
            types: ['class-name'],
            style: { color: 'rgb(38, 127, 153)' },
        },
    ],
};

const vars = {
    border: `1px solid var(${coreReactConstant.TokenNames.colorBorderCodeLineno}, hsla(0deg, 0%, 80%, 0.8))`,
    highlightBackground: `var(${coreReactConstant.TokenNames.colorBgCodeHighlight}, hsla(30deg, 90%, 50%, 0.3))`,
    fontSizeCode: `var(${coreReactConstant.CommonTokenNames.fontSizeCode}, 14px)`,
    lineHeightCode: `var(${coreReactConstant.CommonTokenNames.lineHeightCode}, 1.6)`,
};
const classes = {
    container: css.css({
        MozOsxFontSmoothing: 'grayscale',
        WebkitFontSmoothing: 'antialiased',
        display: 'flex',
        alignItems: 'stretch',
        overflow: 'hidden',
        width: '100%',
        fontSize: vars.fontSizeCode,
        lineHeight: vars.lineHeightCode,
        padding: 0,
        transition: 'max-height 0.5s ease-in-out',
        tabSize: 2,
        fontSmooth: 'always',
        whiteSpace: 'pre',
        wordBreak: 'keep-all',
        wordSpacing: 'normal',
        wordWrap: 'normal',
    }),
    line: css.css({
        boxSizing: 'border-box',
        display: 'flex',
        minWidth: 'fit-content',
        width: '100%',
        padding: '0 6px',
        letterSpacing: 'inherit',
        fontSize: vars.fontSizeCode,
        lineHeight: vars.lineHeightCode,
        height: vars.lineHeightCode,
        overflowWrap: 'inherit',
        tabSize: 'inherit',
        textIndent: 'inherit',
        textRendering: 'inherit',
        textTransform: 'inherit',
        whiteSpace: 'inherit',
        wordBreak: 'inherit',
        wordSpacing: 'inherit',
        wordWrap: 'inherit',
    }),
    linenoLine: css.css({
        justifyContent: 'flex-end',
        padding: '0 4px',
    }),
    highlightLine: css.css({
        background: vars.highlightBackground,
        borderColor: 'transparent',
    }),
    lineno: css.css({
        flex: '0 0 auto',
        overflow: 'hidden',
        boxSizing: 'border-box',
        padding: '0.5rem 0',
        cursor: 'default',
        fontSize: vars.fontSizeCode,
        lineHeight: vars.lineHeightCode,
        userSelect: 'none',
        textAlign: 'right',
        borderRight: vars.border,
    }),
    codes: css.css({
        flex: '1 1 auto',
        overflow: 'overlay',
        boxSizing: 'border-box',
        padding: '0.5rem 0',
        fontSize: vars.fontSizeCode,
        lineHeight: vars.lineHeightCode,
    }),
    codeWrapper: css.css({
        minWidth: '100%',
        width: 'fit-content',
    }),
    codeLine: css.css({
        boxSizing: 'border-box',
        padding: '0 12px',
    }),
};

const languageMap = {
    js: 'javascript',
    ts: 'typescript',
};
const themeToDict = (language, theme) => {
    language = languageMap[language] ?? language;
    const { plain } = theme;
    const base = Object.create(null);
    const themeDict = theme.styles.reduce((acc, themeEntry) => {
        const { types, style, languages } = themeEntry;
        if (languages && !languages.includes(language))
            return acc;
        for (const type of types) {
            const accStyle = { ...acc[type], ...style };
            acc[type] = accStyle;
        }
        return acc;
    }, base);
    themeDict.root = plain;
    themeDict.plain = { ...plain, backgroundColor: undefined };
    return themeDict;
};

const newlineRegex = /\r\n|\r|\n/;
const normalizeEmptyLines = (line) => {
    if (line.length === 0) {
        line.push({
            types: ['plain'],
            content: '\n',
            empty: true,
        });
    }
    else if (line.length === 1 && line[0].content === '') {
        line[0].content = '\n';
        line[0].empty = true;
    }
};
const appendTypes = (types, add) => {
    const typesSize = types.length;
    if (typesSize > 0 && types[typesSize - 1] === add) {
        return types;
    }
    return types.concat(add);
};
const normalizeTokens = (tokens) => {
    const typeArrStack = [[]];
    const tokenArrStack = [tokens];
    const tokenArrIndexStack = [0];
    const tokenArrSizeStack = [tokens.length];
    let currentLine = [];
    const acc = [currentLine];
    for (let stackIndex = 0; stackIndex > -1; --stackIndex) {
        for (let i = 0; (i = tokenArrIndexStack[stackIndex]++) < tokenArrSizeStack[stackIndex];) {
            let content;
            let types = typeArrStack[stackIndex];
            const tokenArr = tokenArrStack[stackIndex];
            const token = tokenArr[i];
            if (typeof token === 'string') {
                types = stackIndex > 0 ? types : ['plain'];
                content = token;
            }
            else {
                types = appendTypes(types, token.type);
                if (token.alias) {
                    types = appendTypes(types, token.alias);
                }
                content = token.content;
            }
            if (typeof content !== 'string') {
                stackIndex += 1;
                typeArrStack.push(types);
                tokenArrStack.push(content);
                tokenArrIndexStack.push(0);
                tokenArrSizeStack.push(content.length);
                continue;
            }
            const splitByNewlines = content.split(newlineRegex);
            const newlineCount = splitByNewlines.length;
            currentLine.push({ types, content: splitByNewlines[0] });
            for (let i = 1; i < newlineCount; i++) {
                normalizeEmptyLines(currentLine);
                acc.push((currentLine = []));
                currentLine.push({ types, content: splitByNewlines[i] });
            }
        }
        typeArrStack.pop();
        tokenArrStack.pop();
        tokenArrIndexStack.pop();
        tokenArrSizeStack.pop();
    }
    normalizeEmptyLines(currentLine);
    return acc;
};

function areSameArray(A1, A2) {
    if (A1 === A2)
        return true;
    const L1 = A1?.length ?? 0;
    const L2 = A2?.length ?? 0;
    if (L1 !== L2)
        return false;
    if (!Array.isArray(A1) || !Array.isArray(A2))
        return L1 === 0;
    for (let i = 0; i < L1; ++i)
        if (A1[i] !== A2[i])
            return false;
    return true;
}

class HighlightLinenos extends React__default.default.Component {
    static displayName = 'HighlightLinenos';
    static propTypes = {
        countOfLines: PropTypes__default.default.number.isRequired,
        highlightLinenos: PropTypes__default.default.array,
    };
    shouldComponentUpdate(nextProps) {
        const props = this.props;
        return (props.countOfLines !== nextProps.countOfLines ||
            !areSameArray(props.highlightLinenos, nextProps.highlightLinenos));
    }
    render() {
        const { countOfLines, highlightLinenos = [] } = this.props;
        const lines = [];
        for (let lineno = 0; lineno < countOfLines; ++lineno) {
            const isHighlight = highlightLinenos.includes(lineno + 1);
            const line = (React__default.default.createElement("div", { key: lineno, className: css.cx(classes.line, classes.linenoLine, isHighlight && classes.highlightLine) },
                React__default.default.createElement("span", { key: lineno }, lineno + 1)));
            lines.push(line);
        }
        return React__default.default.createElement(React__default.default.Fragment, null, lines);
    }
}

class HighlightContent extends React__default.default.Component {
    static displayName = 'HighlightContent';
    static propTypes = {
        code: PropTypes__default.default.string.isRequired,
        codesRef: PropTypes__default.default.any,
        collapsed: PropTypes__default.default.bool.isRequired,
        language: PropTypes__default.default.string.isRequired,
        maxLines: PropTypes__default.default.number.isRequired,
        showLineno: PropTypes__default.default.bool.isRequired,
        theme: PropTypes__default.default.object.isRequired,
        highlightLinenos: PropTypes__default.default.array.isRequired,
        onLinenoWidthChange: PropTypes__default.default.func,
    };
    linenoRef;
    constructor(props) {
        super(props);
        const themeDict = themeToDict(props.language, props.theme);
        const tokens = this.tokenize(props.code, props.language);
        const linenoWidth = props.showLineno
            ? `${Math.max(2, String(tokens.length).length) * 1.1}em`
            : undefined;
        this.state = { linenoWidth, themeDict, tokens };
        this.linenoRef = { current: null };
    }
    shouldComponentUpdate(nextProps, nextState) {
        const props = this.props;
        const state = this.state;
        return (state.linenoWidth !== nextState.linenoWidth ||
            state.themeDict !== nextState.themeDict ||
            state.tokens !== nextState.tokens ||
            props.code !== nextProps.code ||
            props.codesRef !== nextProps.codesRef ||
            props.collapsed !== nextProps.collapsed ||
            props.language !== nextProps.language ||
            props.maxLines !== nextProps.maxLines ||
            props.showLineno !== nextProps.showLineno ||
            !equal.isEqual(props.theme, nextProps.theme) ||
            !equal.isEqual(props.highlightLinenos, nextProps.highlightLinenos));
    }
    render() {
        const { linenoRef, onScroll } = this;
        const { codesRef, collapsed, highlightLinenos, language, maxLines, showLineno = true, } = this.props;
        const { linenoWidth, tokens } = this.state;
        const countOfLines = tokens.length;
        const visibleLines = maxLines > 0 ? Math.min(maxLines, countOfLines) : countOfLines;
        const style = {
            ...this.state.themeDict.root,
            backgroundColor: 'none',
            ...(collapsed
                ? {
                    maxHeight: 0,
                }
                : {
                    maxHeight: `calc(calc(${vars.lineHeightCode} * ${visibleLines + 0.8}) + 6px)`,
                    minHeight: '100%',
                }),
        };
        return (React__default.default.createElement("div", { className: css.cx(classes.container, language ? `prism-code language-${language}` : `prism-code`), style: style },
            showLineno && (React__default.default.createElement("div", { key: "linenos", className: classes.lineno, style: { width: linenoWidth }, ref: linenoRef },
                React__default.default.createElement(HighlightLinenos, { countOfLines: countOfLines, highlightLinenos: highlightLinenos }))),
            React__default.default.createElement("div", { key: "codes", ref: codesRef, className: classes.codes, onScroll: onScroll },
                React__default.default.createElement("div", { className: classes.codeWrapper }, tokens.map((line, lineNo) => {
                    const isHighlight = highlightLinenos.includes(lineNo + 1);
                    const lineProps = this.getLineProps({ line });
                    return (React__default.default.createElement("div", { ...lineProps, key: lineNo, className: css.cx(classes.line, classes.codeLine, isHighlight && classes.highlightLine, lineProps.className) }, line.map((token, key) => (React__default.default.createElement("span", { ...this.getTokenProps({ token }), key: key })))));
                })))));
    }
    componentDidMount() {
        this.props.onLinenoWidthChange?.(this.state.linenoWidth);
    }
    componentDidUpdate(prevProps, prevState) {
        const props = this.props;
        const state = this.state;
        const latestThemeDict = props.language !== prevProps.language || !equal.isEqual(props.theme, prevProps.theme)
            ? themeToDict(props.language, props.theme)
            : state.themeDict;
        if (props.code !== prevProps.code ||
            props.language !== prevProps.language ||
            latestThemeDict !== prevState.themeDict) {
            const nextTokens = this.tokenize(props.code, props.language);
            const linenoWidth = props.showLineno
                ? `${Math.max(2, String(nextTokens.length).length) * 1.1}em`
                : undefined;
            this.setState({ linenoWidth, themeDict: latestThemeDict, tokens: nextTokens });
        }
        if (state.linenoWidth !== prevState.linenoWidth) {
            this.props.onLinenoWidthChange?.(state.linenoWidth);
        }
    }
    onScroll = (e) => {
        const codesArea = e.target;
        if (codesArea == null)
            return;
        const { scrollTop } = codesArea;
        this.linenoRef.current?.scrollTo?.(0, scrollTop);
    };
    tokenize(code, language) {
        const grammar = language ? Prism__default.default.languages[language] : undefined;
        if (grammar) {
            const env = { code, grammar, language, tokens: [] };
            Prism__default.default.hooks.run('before-tokenize', env);
            env.tokens = Prism__default.default.tokenize(env.code, env.grammar);
            Prism__default.default.hooks.run('after-tokenize', env);
            const tokens = normalizeTokens(env.tokens);
            return tokens;
        }
        else {
            const tokens = normalizeTokens([code]);
            return tokens;
        }
    }
    getLineProps(lineInputProps) {
        const { themeDict } = this.state;
        const { key, className, style, line, ...rest } = lineInputProps;
        const output = {
            ...rest,
            className: 'token-line',
            style: undefined,
            key: undefined,
        };
        if (themeDict !== undefined) {
            output.style = themeDict.plain;
        }
        if (style !== undefined) {
            output.style = output.style !== undefined ? { ...output.style, ...style } : style;
        }
        if (key !== undefined)
            output.key = key;
        if (className)
            output.className += ` ${className}`;
        return output;
    }
    getStyleForToken({ types, empty }) {
        const { themeDict } = this.state;
        const typesSize = types.length;
        if (themeDict === undefined) {
            return undefined;
        }
        else if (typesSize === 1 && types[0] === 'plain') {
            return empty ? { display: 'inline-block' } : undefined;
        }
        else if (typesSize === 1 && !empty) {
            return themeDict[types[0]];
        }
        const style = empty ? { display: 'inline-block' } : {};
        for (const type of types) {
            const typeStyle = themeDict[type];
            Object.assign(style, typeStyle);
        }
        return style;
    }
    getTokenProps(tokenInputProps) {
        const { key, className, style, token, ...rest } = tokenInputProps;
        const output = {
            ...rest,
            className: `token ${token.types.join(' ')}`,
            children: token.content,
            style: this.getStyleForToken(token),
            key: undefined,
        };
        if (style !== undefined) {
            output.style = output.style !== undefined ? { ...output.style, ...style } : style;
        }
        if (key !== undefined)
            output.key = key;
        if (className)
            output.className += ` ${className}`;
        return output;
    }
}

class CodeHighlighter extends React__default.default.PureComponent {
    static displayName = 'YozoraCodeHighlighter';
    static propTypes = {
        codesRef: PropTypes__default.default.any,
        collapsed: PropTypes__default.default.bool,
        darken: PropTypes__default.default.bool,
        highlightLinenos: PropTypes__default.default.arrayOf(PropTypes__default.default.number),
        lang: PropTypes__default.default.string,
        maxLines: PropTypes__default.default.number,
        onLinenoWidthChange: PropTypes__default.default.func,
        showLineNo: PropTypes__default.default.bool,
        theme: PropTypes__default.default.any,
        value: PropTypes__default.default.string.isRequired,
    };
    render() {
        const { lang, value: code, darken = true, highlightLinenos = [], maxLines = -1, collapsed = false, showLineNo = true, codesRef, onLinenoWidthChange, } = this.props;
        const theme = this.props.theme ?? (darken ? vscDarkTheme : vscLightTheme);
        return (React__default.default.createElement(HighlightContent, { code: code, codesRef: codesRef, collapsed: collapsed, highlightLinenos: highlightLinenos, language: lang ?? '', maxLines: maxLines, showLineno: showLineNo, theme: theme, onLinenoWidthChange: onLinenoWidthChange }));
    }
}

const githubTheme = {
    plain: {
        color: '#393A34',
        backgroundColor: '#f6f8fa',
    },
    styles: [
        {
            types: ['comment', 'prolog', 'doctype', 'cdata'],
            style: {
                color: '#999988',
                fontStyle: 'italic',
            },
        },
        {
            types: ['namespace'],
            style: {
                opacity: 0.7,
            },
        },
        {
            types: ['string', 'attr-value'],
            style: {
                color: '#e3116c',
            },
        },
        {
            types: ['punctuation', 'operator'],
            style: {
                color: '#393A34',
            },
        },
        {
            types: [
                'entity',
                'url',
                'symbol',
                'number',
                'boolean',
                'variable',
                'constant',
                'property',
                'regex',
                'inserted',
            ],
            style: {
                color: '#36acaa',
            },
        },
        {
            types: ['atrule', 'keyword', 'attr-name', 'selector'],
            style: {
                color: '#00a4db',
            },
        },
        {
            types: ['function', 'deleted', 'tag'],
            style: {
                color: '#d73a49',
            },
        },
        {
            types: ['function-variable'],
            style: {
                color: '#6f42c1',
            },
        },
        {
            types: ['tag', 'selector', 'keyword'],
            style: {
                color: '#00009f',
            },
        },
    ],
};

exports.CodeHighlighter = CodeHighlighter;
exports.HighlightContent = HighlightContent;
exports.HighlightLinenos = HighlightLinenos;
exports.areSameArray = areSameArray;
exports.classes = classes;
exports.default = CodeHighlighter;
exports.githubTheme = githubTheme;
exports.normalizeTokens = normalizeTokens;
exports.themeToDict = themeToDict;
exports.vars = vars;
exports.vscDarkTheme = vscDarkTheme;
exports.vscLightTheme = vscLightTheme;
