import PropTypes from 'prop-types';
import React from 'react';
import { TokenStream } from 'prismjs';

interface IToken {
    types: string[];
    content: string;
    empty?: boolean;
}
interface ILineInputProps {
    key?: React.Key;
    style?: React.CSSProperties;
    className?: string;
    line: IToken[];
    [otherProp: string]: any;
}
interface ILineOutputProps {
    key?: React.Key;
    style?: React.CSSProperties;
    className: string;
    [otherProps: string]: any;
}
interface ITokenInputProps {
    key?: React.Key;
    style?: React.CSSProperties;
    className?: string;
    token: IToken;
    [otherProp: string]: any;
}
interface ITokenOutputProps {
    key?: React.Key;
    style?: React.CSSProperties;
    className: string;
    children: string;
    [otherProp: string]: any;
}
interface IHighlightTokens {
    tokens: IToken[][];
    className?: string;
    style: React.CSSProperties;
    getLineProps(input: ILineInputProps): ILineOutputProps;
    getTokenProps(input: ITokenInputProps): ITokenOutputProps;
}
interface PrismThemeEntry {
    color?: string;
    backgroundColor?: string;
    fontStyle?: 'normal' | 'italic';
    fontWeight?: 'normal' | 'bold' | '100' | '200' | '300' | '400' | '500' | '600' | '700' | '800' | '900';
    textDecorationLine?: 'none' | 'underline' | 'line-through' | 'underline line-through';
    opacity?: number;
    [styleKey: string]: string | number | void;
}
interface IPrismTheme {
    plain: PrismThemeEntry;
    styles: Array<{
        types: string[];
        style: PrismThemeEntry;
        languages?: string[];
    }>;
}
interface IThemeDict {
    root: React.CSSProperties;
    plain: React.CSSProperties;
    [type: string]: React.CSSProperties;
}

interface IProps$2 {
    /**
     * Source code contents
     */
    value: string;
    /**
     * Code language
     */
    lang?: string | null;
    /**
     * Line number of Lines that should be highlighted.
     */
    highlightLinenos?: number[];
    /**
     * Whether the code block is in a collapsed state.
     * @default false
     */
    collapsed?: boolean;
    /**
     * Maximum number of rows displayed
     * @default -1
     */
    maxLines?: number;
    /**
     * Whether should display line numbers.
     * @default true
     */
    showLineNo?: boolean;
    /**
     * If true, use vscDarkTheme as default theme,
     * otherwise use vscLightTheme as default theme.
     * @default true
     */
    darken?: boolean;
    /**
     * Highlight prism theme.
     */
    theme?: IPrismTheme;
    /**
     * Ref of the codes area.
     */
    codesRef?: React.RefCallback<HTMLDivElement> | React.RefObject<HTMLDivElement>;
    /**
     * Callback when linenoWidth changed.
     */
    onLinenoWidthChange?(linenoWidth: React.CSSProperties['width']): void;
}
declare class CodeHighlighter extends React.PureComponent<IProps$2> {
    static readonly displayName = "YozoraCodeHighlighter";
    static readonly propTypes: {
        codesRef: PropTypes.Requireable<any>;
        collapsed: PropTypes.Requireable<boolean>;
        darken: PropTypes.Requireable<boolean>;
        highlightLinenos: any;
        lang: PropTypes.Requireable<string>;
        maxLines: PropTypes.Requireable<number>;
        onLinenoWidthChange: PropTypes.Requireable<(...args: any[]) => any>;
        showLineNo: PropTypes.Requireable<boolean>;
        theme: PropTypes.Requireable<any>;
        value: PropTypes.Validator<string>;
    };
    render(): React.ReactElement;
}

interface IProps$1 {
    countOfLines: number;
    highlightLinenos: number[] | undefined;
}
declare class HighlightLinenos extends React.Component<IProps$1> {
    static readonly displayName = "HighlightLinenos";
    static readonly propTypes: {
        countOfLines: PropTypes.Validator<number>;
        highlightLinenos: PropTypes.Requireable<any[]>;
    };
    shouldComponentUpdate(nextProps: Readonly<IProps$1>): boolean;
    render(): React.ReactElement;
}

interface IProps {
    code: string;
    codesRef: React.RefCallback<HTMLDivElement> | React.RefObject<HTMLDivElement> | undefined;
    collapsed: boolean;
    language: string;
    maxLines: number;
    showLineno: boolean;
    theme: IPrismTheme;
    highlightLinenos: number[];
    onLinenoWidthChange?(linenoWidth: React.CSSProperties['width']): void;
}
interface IState {
    linenoWidth: string | undefined;
    themeDict: IThemeDict;
    tokens: IToken[][];
}
declare class HighlightContent extends React.Component<IProps, IState> {
    static readonly displayName = "HighlightContent";
    static readonly propTypes: {
        code: PropTypes.Validator<string>;
        codesRef: PropTypes.Requireable<any>;
        collapsed: PropTypes.Validator<boolean>;
        language: PropTypes.Validator<string>;
        maxLines: PropTypes.Validator<number>;
        showLineno: PropTypes.Validator<boolean>;
        theme: PropTypes.Validator<object>;
        highlightLinenos: PropTypes.Validator<any[]>;
        onLinenoWidthChange: PropTypes.Requireable<(...args: any[]) => any>;
    };
    protected readonly linenoRef: React.RefObject<HTMLDivElement>;
    constructor(props: IProps);
    shouldComponentUpdate(nextProps: Readonly<IProps>, nextState: Readonly<IState>): boolean;
    render(): React.ReactElement;
    componentDidMount(): void;
    componentDidUpdate(prevProps: Readonly<IProps>, prevState: Readonly<IState>): void;
    protected readonly onScroll: (e: React.UIEvent<HTMLDivElement>) => void;
    protected tokenize(code: string, language: string): IToken[][];
    protected getLineProps(lineInputProps: ILineInputProps): ILineOutputProps;
    protected getStyleForToken({ types, empty }: IToken): React.CSSProperties | undefined;
    protected getTokenProps(tokenInputProps: ITokenInputProps): ITokenOutputProps;
}

/**
 * Generated Prism Theme from VSCode .json Themes
 *
 * @see https://github.com/FormidableLabs/prism-react-renderer/blob/95025358684be04865669bb912e8cf6203c1a391/tools/themeFromVsCode/README.md
 */
declare const vscDarkTheme: IPrismTheme;

/**
 * Generated Prism Theme from VSCode .json Themes
 *
 * @see https://github.com/FormidableLabs/prism-react-renderer/blob/95025358684be04865669bb912e8cf6203c1a391/tools/themeFromVsCode/README.md
 */
declare const vscLightTheme: IPrismTheme;

/**
 * Generated Prism Theme from VSCode .json Themes
 *
 * @see https://github.com/FormidableLabs/prism-react-renderer/blob/d307f34360ecc4f0b4aadde4f72d09fd6dbf0132/src/themes/github.js
 */
declare const githubTheme: IPrismTheme;

declare function areSameArray(A1: unknown[] | undefined, A2: unknown[] | undefined): boolean;

declare const themeToDict: (language: string, theme: IPrismTheme) => IThemeDict;

/**
 * See https://github.com/FormidableLabs/prism-react-renderer/blob/d307f34360ecc4f0b4aadde4f72d09fd6dbf0132/src/utils/normalizeTokens.js
 */

declare const normalizeTokens: (tokens: TokenStream) => IToken[][];

declare const vars: {
    border: string;
    highlightBackground: string;
    fontSizeCode: string;
    lineHeightCode: string;
};
declare const classes: {
    container: string;
    line: string;
    linenoLine: string;
    highlightLine: string;
    lineno: string;
    codes: string;
    codeWrapper: string;
    codeLine: string;
};

export { CodeHighlighter, HighlightContent, HighlightLinenos, type IHighlightTokens, type ILineInputProps, type ILineOutputProps, type IPrismTheme, type IThemeDict, type IToken, type ITokenInputProps, type ITokenOutputProps, areSameArray, classes, CodeHighlighter as default, githubTheme, normalizeTokens, themeToDict, vars, vscDarkTheme, vscLightTheme };
